
/** @ingroup libplayerxdr
@{ */
#ifndef _PLAYERXDR_PACK_H_
#define _PLAYERXDR_PACK_H_

#if defined (WIN32)
  #if defined (PLAYER_STATIC)
    #define PLAYERXDR_EXPORT
  #elif defined (playerxdr_EXPORTS)
    #define PLAYERXDR_EXPORT    __declspec (dllexport)
  #else
    #define PLAYERXDR_EXPORT    __declspec (dllimport)
  #endif
#else
  #define PLAYERXDR_EXPORT
#endif

#include <rpc/types.h>
#include <rpc/xdr.h>

#include <libplayerinterface/player.h>
#include <libplayerinterface/functiontable.h>
#ifdef __cplusplus
  extern "C" {
#endif
#ifndef XDR_ENCODE
  #define XDR_ENCODE 0
#endif
#ifndef XDR_DECODE
  #define XDR_DECODE 1
#endif
#define PLAYERXDR_ENCODE XDR_ENCODE
#define PLAYERXDR_DECODE XDR_DECODE

#define PLAYERXDR_MSGHDR_SIZE 40
#define PLAYERXDR_MAX_MESSAGE_SIZE (4*PLAYER_MAX_MESSAGE_SIZE)
int xdr_player_devaddr_t (XDR* xdrs, player_devaddr_t * msg);
PLAYERXDR_EXPORT int player_devaddr_pack(void* buf, size_t buflen, player_devaddr_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_devaddr_t_copy(player_devaddr_t *dest, const player_devaddr_t *src);
PLAYERXDR_EXPORT void player_devaddr_t_cleanup(const player_devaddr_t *msg);
PLAYERXDR_EXPORT player_devaddr_t * player_devaddr_t_clone(const player_devaddr_t *msg);
PLAYERXDR_EXPORT void player_devaddr_t_free(player_devaddr_t *msg);
PLAYERXDR_EXPORT unsigned int player_devaddr_t_sizeof(player_devaddr_t *msg);
int xdr_player_msghdr_t (XDR* xdrs, player_msghdr_t * msg);
PLAYERXDR_EXPORT int player_msghdr_pack(void* buf, size_t buflen, player_msghdr_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_msghdr_t_copy(player_msghdr_t *dest, const player_msghdr_t *src);
PLAYERXDR_EXPORT void player_msghdr_t_cleanup(const player_msghdr_t *msg);
PLAYERXDR_EXPORT player_msghdr_t * player_msghdr_t_clone(const player_msghdr_t *msg);
PLAYERXDR_EXPORT void player_msghdr_t_free(player_msghdr_t *msg);
PLAYERXDR_EXPORT unsigned int player_msghdr_t_sizeof(player_msghdr_t *msg);
int xdr_player_point_2d_t (XDR* xdrs, player_point_2d_t * msg);
PLAYERXDR_EXPORT int player_point_2d_pack(void* buf, size_t buflen, player_point_2d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_point_2d_t_copy(player_point_2d_t *dest, const player_point_2d_t *src);
PLAYERXDR_EXPORT void player_point_2d_t_cleanup(const player_point_2d_t *msg);
PLAYERXDR_EXPORT player_point_2d_t * player_point_2d_t_clone(const player_point_2d_t *msg);
PLAYERXDR_EXPORT void player_point_2d_t_free(player_point_2d_t *msg);
PLAYERXDR_EXPORT unsigned int player_point_2d_t_sizeof(player_point_2d_t *msg);
int xdr_player_point_3d_t (XDR* xdrs, player_point_3d_t * msg);
PLAYERXDR_EXPORT int player_point_3d_pack(void* buf, size_t buflen, player_point_3d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_point_3d_t_copy(player_point_3d_t *dest, const player_point_3d_t *src);
PLAYERXDR_EXPORT void player_point_3d_t_cleanup(const player_point_3d_t *msg);
PLAYERXDR_EXPORT player_point_3d_t * player_point_3d_t_clone(const player_point_3d_t *msg);
PLAYERXDR_EXPORT void player_point_3d_t_free(player_point_3d_t *msg);
PLAYERXDR_EXPORT unsigned int player_point_3d_t_sizeof(player_point_3d_t *msg);
int xdr_player_orientation_3d_t (XDR* xdrs, player_orientation_3d_t * msg);
PLAYERXDR_EXPORT int player_orientation_3d_pack(void* buf, size_t buflen, player_orientation_3d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_orientation_3d_t_copy(player_orientation_3d_t *dest, const player_orientation_3d_t *src);
PLAYERXDR_EXPORT void player_orientation_3d_t_cleanup(const player_orientation_3d_t *msg);
PLAYERXDR_EXPORT player_orientation_3d_t * player_orientation_3d_t_clone(const player_orientation_3d_t *msg);
PLAYERXDR_EXPORT void player_orientation_3d_t_free(player_orientation_3d_t *msg);
PLAYERXDR_EXPORT unsigned int player_orientation_3d_t_sizeof(player_orientation_3d_t *msg);
int xdr_player_pose2d_t (XDR* xdrs, player_pose2d_t * msg);
PLAYERXDR_EXPORT int player_pose2d_pack(void* buf, size_t buflen, player_pose2d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_pose2d_t_copy(player_pose2d_t *dest, const player_pose2d_t *src);
PLAYERXDR_EXPORT void player_pose2d_t_cleanup(const player_pose2d_t *msg);
PLAYERXDR_EXPORT player_pose2d_t * player_pose2d_t_clone(const player_pose2d_t *msg);
PLAYERXDR_EXPORT void player_pose2d_t_free(player_pose2d_t *msg);
PLAYERXDR_EXPORT unsigned int player_pose2d_t_sizeof(player_pose2d_t *msg);
int xdr_player_pose3d_t (XDR* xdrs, player_pose3d_t * msg);
PLAYERXDR_EXPORT int player_pose3d_pack(void* buf, size_t buflen, player_pose3d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_pose3d_t_copy(player_pose3d_t *dest, const player_pose3d_t *src);
PLAYERXDR_EXPORT void player_pose3d_t_cleanup(const player_pose3d_t *msg);
PLAYERXDR_EXPORT player_pose3d_t * player_pose3d_t_clone(const player_pose3d_t *msg);
PLAYERXDR_EXPORT void player_pose3d_t_free(player_pose3d_t *msg);
PLAYERXDR_EXPORT unsigned int player_pose3d_t_sizeof(player_pose3d_t *msg);
int xdr_player_bbox2d_t (XDR* xdrs, player_bbox2d_t * msg);
PLAYERXDR_EXPORT int player_bbox2d_pack(void* buf, size_t buflen, player_bbox2d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bbox2d_t_copy(player_bbox2d_t *dest, const player_bbox2d_t *src);
PLAYERXDR_EXPORT void player_bbox2d_t_cleanup(const player_bbox2d_t *msg);
PLAYERXDR_EXPORT player_bbox2d_t * player_bbox2d_t_clone(const player_bbox2d_t *msg);
PLAYERXDR_EXPORT void player_bbox2d_t_free(player_bbox2d_t *msg);
PLAYERXDR_EXPORT unsigned int player_bbox2d_t_sizeof(player_bbox2d_t *msg);
int xdr_player_bbox3d_t (XDR* xdrs, player_bbox3d_t * msg);
PLAYERXDR_EXPORT int player_bbox3d_pack(void* buf, size_t buflen, player_bbox3d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bbox3d_t_copy(player_bbox3d_t *dest, const player_bbox3d_t *src);
PLAYERXDR_EXPORT void player_bbox3d_t_cleanup(const player_bbox3d_t *msg);
PLAYERXDR_EXPORT player_bbox3d_t * player_bbox3d_t_clone(const player_bbox3d_t *msg);
PLAYERXDR_EXPORT void player_bbox3d_t_free(player_bbox3d_t *msg);
PLAYERXDR_EXPORT unsigned int player_bbox3d_t_sizeof(player_bbox3d_t *msg);
int xdr_player_blackboard_entry_t (XDR* xdrs, player_blackboard_entry_t * msg);
PLAYERXDR_EXPORT int player_blackboard_entry_pack(void* buf, size_t buflen, player_blackboard_entry_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blackboard_entry_t_copy(player_blackboard_entry_t *dest, const player_blackboard_entry_t *src);
PLAYERXDR_EXPORT void player_blackboard_entry_t_cleanup(const player_blackboard_entry_t *msg);
PLAYERXDR_EXPORT player_blackboard_entry_t * player_blackboard_entry_t_clone(const player_blackboard_entry_t *msg);
PLAYERXDR_EXPORT void player_blackboard_entry_t_free(player_blackboard_entry_t *msg);
PLAYERXDR_EXPORT unsigned int player_blackboard_entry_t_sizeof(player_blackboard_entry_t *msg);
int xdr_player_segment_t (XDR* xdrs, player_segment_t * msg);
PLAYERXDR_EXPORT int player_segment_pack(void* buf, size_t buflen, player_segment_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_segment_t_copy(player_segment_t *dest, const player_segment_t *src);
PLAYERXDR_EXPORT void player_segment_t_cleanup(const player_segment_t *msg);
PLAYERXDR_EXPORT player_segment_t * player_segment_t_clone(const player_segment_t *msg);
PLAYERXDR_EXPORT void player_segment_t_free(player_segment_t *msg);
PLAYERXDR_EXPORT unsigned int player_segment_t_sizeof(player_segment_t *msg);
int xdr_player_extent2d_t (XDR* xdrs, player_extent2d_t * msg);
PLAYERXDR_EXPORT int player_extent2d_pack(void* buf, size_t buflen, player_extent2d_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_extent2d_t_copy(player_extent2d_t *dest, const player_extent2d_t *src);
PLAYERXDR_EXPORT void player_extent2d_t_cleanup(const player_extent2d_t *msg);
PLAYERXDR_EXPORT player_extent2d_t * player_extent2d_t_clone(const player_extent2d_t *msg);
PLAYERXDR_EXPORT void player_extent2d_t_free(player_extent2d_t *msg);
PLAYERXDR_EXPORT unsigned int player_extent2d_t_sizeof(player_extent2d_t *msg);
int xdr_player_color_t (XDR* xdrs, player_color_t * msg);
PLAYERXDR_EXPORT int player_color_pack(void* buf, size_t buflen, player_color_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_color_t_copy(player_color_t *dest, const player_color_t *src);
PLAYERXDR_EXPORT void player_color_t_cleanup(const player_color_t *msg);
PLAYERXDR_EXPORT player_color_t * player_color_t_clone(const player_color_t *msg);
PLAYERXDR_EXPORT void player_color_t_free(player_color_t *msg);
PLAYERXDR_EXPORT unsigned int player_color_t_sizeof(player_color_t *msg);
int xdr_player_bool_t (XDR* xdrs, player_bool_t * msg);
PLAYERXDR_EXPORT int player_bool_pack(void* buf, size_t buflen, player_bool_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bool_t_copy(player_bool_t *dest, const player_bool_t *src);
PLAYERXDR_EXPORT void player_bool_t_cleanup(const player_bool_t *msg);
PLAYERXDR_EXPORT player_bool_t * player_bool_t_clone(const player_bool_t *msg);
PLAYERXDR_EXPORT void player_bool_t_free(player_bool_t *msg);
PLAYERXDR_EXPORT unsigned int player_bool_t_sizeof(player_bool_t *msg);
int xdr_player_uint32_t (XDR* xdrs, player_uint32_t * msg);
PLAYERXDR_EXPORT int player_uint32_pack(void* buf, size_t buflen, player_uint32_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_uint32_t_copy(player_uint32_t *dest, const player_uint32_t *src);
PLAYERXDR_EXPORT void player_uint32_t_cleanup(const player_uint32_t *msg);
PLAYERXDR_EXPORT player_uint32_t * player_uint32_t_clone(const player_uint32_t *msg);
PLAYERXDR_EXPORT void player_uint32_t_free(player_uint32_t *msg);
PLAYERXDR_EXPORT unsigned int player_uint32_t_sizeof(player_uint32_t *msg);
int xdr_player_capabilities_req_t (XDR* xdrs, player_capabilities_req_t * msg);
PLAYERXDR_EXPORT int player_capabilities_req_pack(void* buf, size_t buflen, player_capabilities_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_capabilities_req_t_copy(player_capabilities_req_t *dest, const player_capabilities_req_t *src);
PLAYERXDR_EXPORT void player_capabilities_req_t_cleanup(const player_capabilities_req_t *msg);
PLAYERXDR_EXPORT player_capabilities_req_t * player_capabilities_req_t_clone(const player_capabilities_req_t *msg);
PLAYERXDR_EXPORT void player_capabilities_req_t_free(player_capabilities_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_capabilities_req_t_sizeof(player_capabilities_req_t *msg);
int xdr_player_boolprop_req_t (XDR* xdrs, player_boolprop_req_t * msg);
PLAYERXDR_EXPORT int player_boolprop_req_pack(void* buf, size_t buflen, player_boolprop_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_boolprop_req_t_copy(player_boolprop_req_t *dest, const player_boolprop_req_t *src);
PLAYERXDR_EXPORT void player_boolprop_req_t_cleanup(const player_boolprop_req_t *msg);
PLAYERXDR_EXPORT player_boolprop_req_t * player_boolprop_req_t_clone(const player_boolprop_req_t *msg);
PLAYERXDR_EXPORT void player_boolprop_req_t_free(player_boolprop_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_boolprop_req_t_sizeof(player_boolprop_req_t *msg);
int xdr_player_intprop_req_t (XDR* xdrs, player_intprop_req_t * msg);
PLAYERXDR_EXPORT int player_intprop_req_pack(void* buf, size_t buflen, player_intprop_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_intprop_req_t_copy(player_intprop_req_t *dest, const player_intprop_req_t *src);
PLAYERXDR_EXPORT void player_intprop_req_t_cleanup(const player_intprop_req_t *msg);
PLAYERXDR_EXPORT player_intprop_req_t * player_intprop_req_t_clone(const player_intprop_req_t *msg);
PLAYERXDR_EXPORT void player_intprop_req_t_free(player_intprop_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_intprop_req_t_sizeof(player_intprop_req_t *msg);
int xdr_player_dblprop_req_t (XDR* xdrs, player_dblprop_req_t * msg);
PLAYERXDR_EXPORT int player_dblprop_req_pack(void* buf, size_t buflen, player_dblprop_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_dblprop_req_t_copy(player_dblprop_req_t *dest, const player_dblprop_req_t *src);
PLAYERXDR_EXPORT void player_dblprop_req_t_cleanup(const player_dblprop_req_t *msg);
PLAYERXDR_EXPORT player_dblprop_req_t * player_dblprop_req_t_clone(const player_dblprop_req_t *msg);
PLAYERXDR_EXPORT void player_dblprop_req_t_free(player_dblprop_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_dblprop_req_t_sizeof(player_dblprop_req_t *msg);
int xdr_player_strprop_req_t (XDR* xdrs, player_strprop_req_t * msg);
PLAYERXDR_EXPORT int player_strprop_req_pack(void* buf, size_t buflen, player_strprop_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_strprop_req_t_copy(player_strprop_req_t *dest, const player_strprop_req_t *src);
PLAYERXDR_EXPORT void player_strprop_req_t_cleanup(const player_strprop_req_t *msg);
PLAYERXDR_EXPORT player_strprop_req_t * player_strprop_req_t_clone(const player_strprop_req_t *msg);
PLAYERXDR_EXPORT void player_strprop_req_t_free(player_strprop_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_strprop_req_t_sizeof(player_strprop_req_t *msg);
int xdr_player_device_devlist_t (XDR* xdrs, player_device_devlist_t * msg);
PLAYERXDR_EXPORT int player_device_devlist_pack(void* buf, size_t buflen, player_device_devlist_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_devlist_t_copy(player_device_devlist_t *dest, const player_device_devlist_t *src);
PLAYERXDR_EXPORT void player_device_devlist_t_cleanup(const player_device_devlist_t *msg);
PLAYERXDR_EXPORT player_device_devlist_t * player_device_devlist_t_clone(const player_device_devlist_t *msg);
PLAYERXDR_EXPORT void player_device_devlist_t_free(player_device_devlist_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_devlist_t_sizeof(player_device_devlist_t *msg);
int xdr_player_device_driverinfo_t (XDR* xdrs, player_device_driverinfo_t * msg);
PLAYERXDR_EXPORT int player_device_driverinfo_pack(void* buf, size_t buflen, player_device_driverinfo_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_driverinfo_t_copy(player_device_driverinfo_t *dest, const player_device_driverinfo_t *src);
PLAYERXDR_EXPORT void player_device_driverinfo_t_cleanup(const player_device_driverinfo_t *msg);
PLAYERXDR_EXPORT player_device_driverinfo_t * player_device_driverinfo_t_clone(const player_device_driverinfo_t *msg);
PLAYERXDR_EXPORT void player_device_driverinfo_t_free(player_device_driverinfo_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_driverinfo_t_sizeof(player_device_driverinfo_t *msg);
int xdr_player_device_req_t (XDR* xdrs, player_device_req_t * msg);
PLAYERXDR_EXPORT int player_device_req_pack(void* buf, size_t buflen, player_device_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_req_t_copy(player_device_req_t *dest, const player_device_req_t *src);
PLAYERXDR_EXPORT void player_device_req_t_cleanup(const player_device_req_t *msg);
PLAYERXDR_EXPORT player_device_req_t * player_device_req_t_clone(const player_device_req_t *msg);
PLAYERXDR_EXPORT void player_device_req_t_free(player_device_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_req_t_sizeof(player_device_req_t *msg);
int xdr_player_device_datamode_req_t (XDR* xdrs, player_device_datamode_req_t * msg);
PLAYERXDR_EXPORT int player_device_datamode_req_pack(void* buf, size_t buflen, player_device_datamode_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_datamode_req_t_copy(player_device_datamode_req_t *dest, const player_device_datamode_req_t *src);
PLAYERXDR_EXPORT void player_device_datamode_req_t_cleanup(const player_device_datamode_req_t *msg);
PLAYERXDR_EXPORT player_device_datamode_req_t * player_device_datamode_req_t_clone(const player_device_datamode_req_t *msg);
PLAYERXDR_EXPORT void player_device_datamode_req_t_free(player_device_datamode_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_datamode_req_t_sizeof(player_device_datamode_req_t *msg);
int xdr_player_device_auth_req_t (XDR* xdrs, player_device_auth_req_t * msg);
PLAYERXDR_EXPORT int player_device_auth_req_pack(void* buf, size_t buflen, player_device_auth_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_auth_req_t_copy(player_device_auth_req_t *dest, const player_device_auth_req_t *src);
PLAYERXDR_EXPORT void player_device_auth_req_t_cleanup(const player_device_auth_req_t *msg);
PLAYERXDR_EXPORT player_device_auth_req_t * player_device_auth_req_t_clone(const player_device_auth_req_t *msg);
PLAYERXDR_EXPORT void player_device_auth_req_t_free(player_device_auth_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_auth_req_t_sizeof(player_device_auth_req_t *msg);
int xdr_player_device_nameservice_req_t (XDR* xdrs, player_device_nameservice_req_t * msg);
PLAYERXDR_EXPORT int player_device_nameservice_req_pack(void* buf, size_t buflen, player_device_nameservice_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_device_nameservice_req_t_copy(player_device_nameservice_req_t *dest, const player_device_nameservice_req_t *src);
PLAYERXDR_EXPORT void player_device_nameservice_req_t_cleanup(const player_device_nameservice_req_t *msg);
PLAYERXDR_EXPORT player_device_nameservice_req_t * player_device_nameservice_req_t_clone(const player_device_nameservice_req_t *msg);
PLAYERXDR_EXPORT void player_device_nameservice_req_t_free(player_device_nameservice_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_device_nameservice_req_t_sizeof(player_device_nameservice_req_t *msg);
int xdr_player_add_replace_rule_req_t (XDR* xdrs, player_add_replace_rule_req_t * msg);
PLAYERXDR_EXPORT int player_add_replace_rule_req_pack(void* buf, size_t buflen, player_add_replace_rule_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_add_replace_rule_req_t_copy(player_add_replace_rule_req_t *dest, const player_add_replace_rule_req_t *src);
PLAYERXDR_EXPORT void player_add_replace_rule_req_t_cleanup(const player_add_replace_rule_req_t *msg);
PLAYERXDR_EXPORT player_add_replace_rule_req_t * player_add_replace_rule_req_t_clone(const player_add_replace_rule_req_t *msg);
PLAYERXDR_EXPORT void player_add_replace_rule_req_t_free(player_add_replace_rule_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_add_replace_rule_req_t_sizeof(player_add_replace_rule_req_t *msg);
int xdr_player_power_data_t (XDR* xdrs, player_power_data_t * msg);
PLAYERXDR_EXPORT int player_power_data_pack(void* buf, size_t buflen, player_power_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_power_data_t_copy(player_power_data_t *dest, const player_power_data_t *src);
PLAYERXDR_EXPORT void player_power_data_t_cleanup(const player_power_data_t *msg);
PLAYERXDR_EXPORT player_power_data_t * player_power_data_t_clone(const player_power_data_t *msg);
PLAYERXDR_EXPORT void player_power_data_t_free(player_power_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_power_data_t_sizeof(player_power_data_t *msg);
int xdr_player_power_chargepolicy_config_t (XDR* xdrs, player_power_chargepolicy_config_t * msg);
PLAYERXDR_EXPORT int player_power_chargepolicy_config_pack(void* buf, size_t buflen, player_power_chargepolicy_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_power_chargepolicy_config_t_copy(player_power_chargepolicy_config_t *dest, const player_power_chargepolicy_config_t *src);
PLAYERXDR_EXPORT void player_power_chargepolicy_config_t_cleanup(const player_power_chargepolicy_config_t *msg);
PLAYERXDR_EXPORT player_power_chargepolicy_config_t * player_power_chargepolicy_config_t_clone(const player_power_chargepolicy_config_t *msg);
PLAYERXDR_EXPORT void player_power_chargepolicy_config_t_free(player_power_chargepolicy_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_power_chargepolicy_config_t_sizeof(player_power_chargepolicy_config_t *msg);
int xdr_player_gripper_data_t (XDR* xdrs, player_gripper_data_t * msg);
PLAYERXDR_EXPORT int player_gripper_data_pack(void* buf, size_t buflen, player_gripper_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_gripper_data_t_copy(player_gripper_data_t *dest, const player_gripper_data_t *src);
PLAYERXDR_EXPORT void player_gripper_data_t_cleanup(const player_gripper_data_t *msg);
PLAYERXDR_EXPORT player_gripper_data_t * player_gripper_data_t_clone(const player_gripper_data_t *msg);
PLAYERXDR_EXPORT void player_gripper_data_t_free(player_gripper_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_gripper_data_t_sizeof(player_gripper_data_t *msg);
int xdr_player_gripper_geom_t (XDR* xdrs, player_gripper_geom_t * msg);
PLAYERXDR_EXPORT int player_gripper_geom_pack(void* buf, size_t buflen, player_gripper_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_gripper_geom_t_copy(player_gripper_geom_t *dest, const player_gripper_geom_t *src);
PLAYERXDR_EXPORT void player_gripper_geom_t_cleanup(const player_gripper_geom_t *msg);
PLAYERXDR_EXPORT player_gripper_geom_t * player_gripper_geom_t_clone(const player_gripper_geom_t *msg);
PLAYERXDR_EXPORT void player_gripper_geom_t_free(player_gripper_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_gripper_geom_t_sizeof(player_gripper_geom_t *msg);
int xdr_player_position2d_data_t (XDR* xdrs, player_position2d_data_t * msg);
PLAYERXDR_EXPORT int player_position2d_data_pack(void* buf, size_t buflen, player_position2d_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_data_t_copy(player_position2d_data_t *dest, const player_position2d_data_t *src);
PLAYERXDR_EXPORT void player_position2d_data_t_cleanup(const player_position2d_data_t *msg);
PLAYERXDR_EXPORT player_position2d_data_t * player_position2d_data_t_clone(const player_position2d_data_t *msg);
PLAYERXDR_EXPORT void player_position2d_data_t_free(player_position2d_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_data_t_sizeof(player_position2d_data_t *msg);
int xdr_player_position2d_cmd_vel_t (XDR* xdrs, player_position2d_cmd_vel_t * msg);
PLAYERXDR_EXPORT int player_position2d_cmd_vel_pack(void* buf, size_t buflen, player_position2d_cmd_vel_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_vel_t_copy(player_position2d_cmd_vel_t *dest, const player_position2d_cmd_vel_t *src);
PLAYERXDR_EXPORT void player_position2d_cmd_vel_t_cleanup(const player_position2d_cmd_vel_t *msg);
PLAYERXDR_EXPORT player_position2d_cmd_vel_t * player_position2d_cmd_vel_t_clone(const player_position2d_cmd_vel_t *msg);
PLAYERXDR_EXPORT void player_position2d_cmd_vel_t_free(player_position2d_cmd_vel_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_vel_t_sizeof(player_position2d_cmd_vel_t *msg);
int xdr_player_position2d_cmd_pos_t (XDR* xdrs, player_position2d_cmd_pos_t * msg);
PLAYERXDR_EXPORT int player_position2d_cmd_pos_pack(void* buf, size_t buflen, player_position2d_cmd_pos_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_pos_t_copy(player_position2d_cmd_pos_t *dest, const player_position2d_cmd_pos_t *src);
PLAYERXDR_EXPORT void player_position2d_cmd_pos_t_cleanup(const player_position2d_cmd_pos_t *msg);
PLAYERXDR_EXPORT player_position2d_cmd_pos_t * player_position2d_cmd_pos_t_clone(const player_position2d_cmd_pos_t *msg);
PLAYERXDR_EXPORT void player_position2d_cmd_pos_t_free(player_position2d_cmd_pos_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_pos_t_sizeof(player_position2d_cmd_pos_t *msg);
int xdr_player_position2d_cmd_car_t (XDR* xdrs, player_position2d_cmd_car_t * msg);
PLAYERXDR_EXPORT int player_position2d_cmd_car_pack(void* buf, size_t buflen, player_position2d_cmd_car_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_car_t_copy(player_position2d_cmd_car_t *dest, const player_position2d_cmd_car_t *src);
PLAYERXDR_EXPORT void player_position2d_cmd_car_t_cleanup(const player_position2d_cmd_car_t *msg);
PLAYERXDR_EXPORT player_position2d_cmd_car_t * player_position2d_cmd_car_t_clone(const player_position2d_cmd_car_t *msg);
PLAYERXDR_EXPORT void player_position2d_cmd_car_t_free(player_position2d_cmd_car_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_car_t_sizeof(player_position2d_cmd_car_t *msg);
int xdr_player_position2d_cmd_vel_head_t (XDR* xdrs, player_position2d_cmd_vel_head_t * msg);
PLAYERXDR_EXPORT int player_position2d_cmd_vel_head_pack(void* buf, size_t buflen, player_position2d_cmd_vel_head_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_vel_head_t_copy(player_position2d_cmd_vel_head_t *dest, const player_position2d_cmd_vel_head_t *src);
PLAYERXDR_EXPORT void player_position2d_cmd_vel_head_t_cleanup(const player_position2d_cmd_vel_head_t *msg);
PLAYERXDR_EXPORT player_position2d_cmd_vel_head_t * player_position2d_cmd_vel_head_t_clone(const player_position2d_cmd_vel_head_t *msg);
PLAYERXDR_EXPORT void player_position2d_cmd_vel_head_t_free(player_position2d_cmd_vel_head_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_cmd_vel_head_t_sizeof(player_position2d_cmd_vel_head_t *msg);
int xdr_player_position2d_geom_t (XDR* xdrs, player_position2d_geom_t * msg);
PLAYERXDR_EXPORT int player_position2d_geom_pack(void* buf, size_t buflen, player_position2d_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_geom_t_copy(player_position2d_geom_t *dest, const player_position2d_geom_t *src);
PLAYERXDR_EXPORT void player_position2d_geom_t_cleanup(const player_position2d_geom_t *msg);
PLAYERXDR_EXPORT player_position2d_geom_t * player_position2d_geom_t_clone(const player_position2d_geom_t *msg);
PLAYERXDR_EXPORT void player_position2d_geom_t_free(player_position2d_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_geom_t_sizeof(player_position2d_geom_t *msg);
int xdr_player_position2d_power_config_t (XDR* xdrs, player_position2d_power_config_t * msg);
PLAYERXDR_EXPORT int player_position2d_power_config_pack(void* buf, size_t buflen, player_position2d_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_power_config_t_copy(player_position2d_power_config_t *dest, const player_position2d_power_config_t *src);
PLAYERXDR_EXPORT void player_position2d_power_config_t_cleanup(const player_position2d_power_config_t *msg);
PLAYERXDR_EXPORT player_position2d_power_config_t * player_position2d_power_config_t_clone(const player_position2d_power_config_t *msg);
PLAYERXDR_EXPORT void player_position2d_power_config_t_free(player_position2d_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_power_config_t_sizeof(player_position2d_power_config_t *msg);
int xdr_player_position2d_velocity_mode_config_t (XDR* xdrs, player_position2d_velocity_mode_config_t * msg);
PLAYERXDR_EXPORT int player_position2d_velocity_mode_config_pack(void* buf, size_t buflen, player_position2d_velocity_mode_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_velocity_mode_config_t_copy(player_position2d_velocity_mode_config_t *dest, const player_position2d_velocity_mode_config_t *src);
PLAYERXDR_EXPORT void player_position2d_velocity_mode_config_t_cleanup(const player_position2d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT player_position2d_velocity_mode_config_t * player_position2d_velocity_mode_config_t_clone(const player_position2d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT void player_position2d_velocity_mode_config_t_free(player_position2d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_velocity_mode_config_t_sizeof(player_position2d_velocity_mode_config_t *msg);
int xdr_player_position2d_position_mode_req_t (XDR* xdrs, player_position2d_position_mode_req_t * msg);
PLAYERXDR_EXPORT int player_position2d_position_mode_req_pack(void* buf, size_t buflen, player_position2d_position_mode_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_position_mode_req_t_copy(player_position2d_position_mode_req_t *dest, const player_position2d_position_mode_req_t *src);
PLAYERXDR_EXPORT void player_position2d_position_mode_req_t_cleanup(const player_position2d_position_mode_req_t *msg);
PLAYERXDR_EXPORT player_position2d_position_mode_req_t * player_position2d_position_mode_req_t_clone(const player_position2d_position_mode_req_t *msg);
PLAYERXDR_EXPORT void player_position2d_position_mode_req_t_free(player_position2d_position_mode_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_position_mode_req_t_sizeof(player_position2d_position_mode_req_t *msg);
int xdr_player_position2d_set_odom_req_t (XDR* xdrs, player_position2d_set_odom_req_t * msg);
PLAYERXDR_EXPORT int player_position2d_set_odom_req_pack(void* buf, size_t buflen, player_position2d_set_odom_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_set_odom_req_t_copy(player_position2d_set_odom_req_t *dest, const player_position2d_set_odom_req_t *src);
PLAYERXDR_EXPORT void player_position2d_set_odom_req_t_cleanup(const player_position2d_set_odom_req_t *msg);
PLAYERXDR_EXPORT player_position2d_set_odom_req_t * player_position2d_set_odom_req_t_clone(const player_position2d_set_odom_req_t *msg);
PLAYERXDR_EXPORT void player_position2d_set_odom_req_t_free(player_position2d_set_odom_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_set_odom_req_t_sizeof(player_position2d_set_odom_req_t *msg);
int xdr_player_position2d_speed_pid_req_t (XDR* xdrs, player_position2d_speed_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position2d_speed_pid_req_pack(void* buf, size_t buflen, player_position2d_speed_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_speed_pid_req_t_copy(player_position2d_speed_pid_req_t *dest, const player_position2d_speed_pid_req_t *src);
PLAYERXDR_EXPORT void player_position2d_speed_pid_req_t_cleanup(const player_position2d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT player_position2d_speed_pid_req_t * player_position2d_speed_pid_req_t_clone(const player_position2d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position2d_speed_pid_req_t_free(player_position2d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_speed_pid_req_t_sizeof(player_position2d_speed_pid_req_t *msg);
int xdr_player_position2d_position_pid_req_t (XDR* xdrs, player_position2d_position_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position2d_position_pid_req_pack(void* buf, size_t buflen, player_position2d_position_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_position_pid_req_t_copy(player_position2d_position_pid_req_t *dest, const player_position2d_position_pid_req_t *src);
PLAYERXDR_EXPORT void player_position2d_position_pid_req_t_cleanup(const player_position2d_position_pid_req_t *msg);
PLAYERXDR_EXPORT player_position2d_position_pid_req_t * player_position2d_position_pid_req_t_clone(const player_position2d_position_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position2d_position_pid_req_t_free(player_position2d_position_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_position_pid_req_t_sizeof(player_position2d_position_pid_req_t *msg);
int xdr_player_position2d_speed_prof_req_t (XDR* xdrs, player_position2d_speed_prof_req_t * msg);
PLAYERXDR_EXPORT int player_position2d_speed_prof_req_pack(void* buf, size_t buflen, player_position2d_speed_prof_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position2d_speed_prof_req_t_copy(player_position2d_speed_prof_req_t *dest, const player_position2d_speed_prof_req_t *src);
PLAYERXDR_EXPORT void player_position2d_speed_prof_req_t_cleanup(const player_position2d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT player_position2d_speed_prof_req_t * player_position2d_speed_prof_req_t_clone(const player_position2d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT void player_position2d_speed_prof_req_t_free(player_position2d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position2d_speed_prof_req_t_sizeof(player_position2d_speed_prof_req_t *msg);
int xdr_player_sonar_data_t (XDR* xdrs, player_sonar_data_t * msg);
PLAYERXDR_EXPORT int player_sonar_data_pack(void* buf, size_t buflen, player_sonar_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_sonar_data_t_copy(player_sonar_data_t *dest, const player_sonar_data_t *src);
PLAYERXDR_EXPORT void player_sonar_data_t_cleanup(const player_sonar_data_t *msg);
PLAYERXDR_EXPORT player_sonar_data_t * player_sonar_data_t_clone(const player_sonar_data_t *msg);
PLAYERXDR_EXPORT void player_sonar_data_t_free(player_sonar_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_sonar_data_t_sizeof(player_sonar_data_t *msg);
int xdr_player_sonar_geom_t (XDR* xdrs, player_sonar_geom_t * msg);
PLAYERXDR_EXPORT int player_sonar_geom_pack(void* buf, size_t buflen, player_sonar_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_sonar_geom_t_copy(player_sonar_geom_t *dest, const player_sonar_geom_t *src);
PLAYERXDR_EXPORT void player_sonar_geom_t_cleanup(const player_sonar_geom_t *msg);
PLAYERXDR_EXPORT player_sonar_geom_t * player_sonar_geom_t_clone(const player_sonar_geom_t *msg);
PLAYERXDR_EXPORT void player_sonar_geom_t_free(player_sonar_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_sonar_geom_t_sizeof(player_sonar_geom_t *msg);
int xdr_player_sonar_power_config_t (XDR* xdrs, player_sonar_power_config_t * msg);
PLAYERXDR_EXPORT int player_sonar_power_config_pack(void* buf, size_t buflen, player_sonar_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_sonar_power_config_t_copy(player_sonar_power_config_t *dest, const player_sonar_power_config_t *src);
PLAYERXDR_EXPORT void player_sonar_power_config_t_cleanup(const player_sonar_power_config_t *msg);
PLAYERXDR_EXPORT player_sonar_power_config_t * player_sonar_power_config_t_clone(const player_sonar_power_config_t *msg);
PLAYERXDR_EXPORT void player_sonar_power_config_t_free(player_sonar_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_sonar_power_config_t_sizeof(player_sonar_power_config_t *msg);
int xdr_player_laser_data_t (XDR* xdrs, player_laser_data_t * msg);
PLAYERXDR_EXPORT int player_laser_data_pack(void* buf, size_t buflen, player_laser_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_data_t_copy(player_laser_data_t *dest, const player_laser_data_t *src);
PLAYERXDR_EXPORT void player_laser_data_t_cleanup(const player_laser_data_t *msg);
PLAYERXDR_EXPORT player_laser_data_t * player_laser_data_t_clone(const player_laser_data_t *msg);
PLAYERXDR_EXPORT void player_laser_data_t_free(player_laser_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_data_t_sizeof(player_laser_data_t *msg);
int xdr_player_laser_data_scanpose_t (XDR* xdrs, player_laser_data_scanpose_t * msg);
PLAYERXDR_EXPORT int player_laser_data_scanpose_pack(void* buf, size_t buflen, player_laser_data_scanpose_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_data_scanpose_t_copy(player_laser_data_scanpose_t *dest, const player_laser_data_scanpose_t *src);
PLAYERXDR_EXPORT void player_laser_data_scanpose_t_cleanup(const player_laser_data_scanpose_t *msg);
PLAYERXDR_EXPORT player_laser_data_scanpose_t * player_laser_data_scanpose_t_clone(const player_laser_data_scanpose_t *msg);
PLAYERXDR_EXPORT void player_laser_data_scanpose_t_free(player_laser_data_scanpose_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_data_scanpose_t_sizeof(player_laser_data_scanpose_t *msg);
int xdr_player_laser_data_scanangle_t (XDR* xdrs, player_laser_data_scanangle_t * msg);
PLAYERXDR_EXPORT int player_laser_data_scanangle_pack(void* buf, size_t buflen, player_laser_data_scanangle_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_data_scanangle_t_copy(player_laser_data_scanangle_t *dest, const player_laser_data_scanangle_t *src);
PLAYERXDR_EXPORT void player_laser_data_scanangle_t_cleanup(const player_laser_data_scanangle_t *msg);
PLAYERXDR_EXPORT player_laser_data_scanangle_t * player_laser_data_scanangle_t_clone(const player_laser_data_scanangle_t *msg);
PLAYERXDR_EXPORT void player_laser_data_scanangle_t_free(player_laser_data_scanangle_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_data_scanangle_t_sizeof(player_laser_data_scanangle_t *msg);
int xdr_player_laser_geom_t (XDR* xdrs, player_laser_geom_t * msg);
PLAYERXDR_EXPORT int player_laser_geom_pack(void* buf, size_t buflen, player_laser_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_geom_t_copy(player_laser_geom_t *dest, const player_laser_geom_t *src);
PLAYERXDR_EXPORT void player_laser_geom_t_cleanup(const player_laser_geom_t *msg);
PLAYERXDR_EXPORT player_laser_geom_t * player_laser_geom_t_clone(const player_laser_geom_t *msg);
PLAYERXDR_EXPORT void player_laser_geom_t_free(player_laser_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_geom_t_sizeof(player_laser_geom_t *msg);
int xdr_player_laser_config_t (XDR* xdrs, player_laser_config_t * msg);
PLAYERXDR_EXPORT int player_laser_config_pack(void* buf, size_t buflen, player_laser_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_config_t_copy(player_laser_config_t *dest, const player_laser_config_t *src);
PLAYERXDR_EXPORT void player_laser_config_t_cleanup(const player_laser_config_t *msg);
PLAYERXDR_EXPORT player_laser_config_t * player_laser_config_t_clone(const player_laser_config_t *msg);
PLAYERXDR_EXPORT void player_laser_config_t_free(player_laser_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_config_t_sizeof(player_laser_config_t *msg);
int xdr_player_laser_power_config_t (XDR* xdrs, player_laser_power_config_t * msg);
PLAYERXDR_EXPORT int player_laser_power_config_pack(void* buf, size_t buflen, player_laser_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_power_config_t_copy(player_laser_power_config_t *dest, const player_laser_power_config_t *src);
PLAYERXDR_EXPORT void player_laser_power_config_t_cleanup(const player_laser_power_config_t *msg);
PLAYERXDR_EXPORT player_laser_power_config_t * player_laser_power_config_t_clone(const player_laser_power_config_t *msg);
PLAYERXDR_EXPORT void player_laser_power_config_t_free(player_laser_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_power_config_t_sizeof(player_laser_power_config_t *msg);
int xdr_player_laser_get_id_config_t (XDR* xdrs, player_laser_get_id_config_t * msg);
PLAYERXDR_EXPORT int player_laser_get_id_config_pack(void* buf, size_t buflen, player_laser_get_id_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_get_id_config_t_copy(player_laser_get_id_config_t *dest, const player_laser_get_id_config_t *src);
PLAYERXDR_EXPORT void player_laser_get_id_config_t_cleanup(const player_laser_get_id_config_t *msg);
PLAYERXDR_EXPORT player_laser_get_id_config_t * player_laser_get_id_config_t_clone(const player_laser_get_id_config_t *msg);
PLAYERXDR_EXPORT void player_laser_get_id_config_t_free(player_laser_get_id_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_get_id_config_t_sizeof(player_laser_get_id_config_t *msg);
int xdr_player_laser_set_filter_config_t (XDR* xdrs, player_laser_set_filter_config_t * msg);
PLAYERXDR_EXPORT int player_laser_set_filter_config_pack(void* buf, size_t buflen, player_laser_set_filter_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_laser_set_filter_config_t_copy(player_laser_set_filter_config_t *dest, const player_laser_set_filter_config_t *src);
PLAYERXDR_EXPORT void player_laser_set_filter_config_t_cleanup(const player_laser_set_filter_config_t *msg);
PLAYERXDR_EXPORT player_laser_set_filter_config_t * player_laser_set_filter_config_t_clone(const player_laser_set_filter_config_t *msg);
PLAYERXDR_EXPORT void player_laser_set_filter_config_t_free(player_laser_set_filter_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_laser_set_filter_config_t_sizeof(player_laser_set_filter_config_t *msg);
int xdr_player_blobfinder_blob_t (XDR* xdrs, player_blobfinder_blob_t * msg);
PLAYERXDR_EXPORT int player_blobfinder_blob_pack(void* buf, size_t buflen, player_blobfinder_blob_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blobfinder_blob_t_copy(player_blobfinder_blob_t *dest, const player_blobfinder_blob_t *src);
PLAYERXDR_EXPORT void player_blobfinder_blob_t_cleanup(const player_blobfinder_blob_t *msg);
PLAYERXDR_EXPORT player_blobfinder_blob_t * player_blobfinder_blob_t_clone(const player_blobfinder_blob_t *msg);
PLAYERXDR_EXPORT void player_blobfinder_blob_t_free(player_blobfinder_blob_t *msg);
PLAYERXDR_EXPORT unsigned int player_blobfinder_blob_t_sizeof(player_blobfinder_blob_t *msg);
int xdr_player_blobfinder_data_t (XDR* xdrs, player_blobfinder_data_t * msg);
PLAYERXDR_EXPORT int player_blobfinder_data_pack(void* buf, size_t buflen, player_blobfinder_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blobfinder_data_t_copy(player_blobfinder_data_t *dest, const player_blobfinder_data_t *src);
PLAYERXDR_EXPORT void player_blobfinder_data_t_cleanup(const player_blobfinder_data_t *msg);
PLAYERXDR_EXPORT player_blobfinder_data_t * player_blobfinder_data_t_clone(const player_blobfinder_data_t *msg);
PLAYERXDR_EXPORT void player_blobfinder_data_t_free(player_blobfinder_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_blobfinder_data_t_sizeof(player_blobfinder_data_t *msg);
int xdr_player_blobfinder_color_config_t (XDR* xdrs, player_blobfinder_color_config_t * msg);
PLAYERXDR_EXPORT int player_blobfinder_color_config_pack(void* buf, size_t buflen, player_blobfinder_color_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blobfinder_color_config_t_copy(player_blobfinder_color_config_t *dest, const player_blobfinder_color_config_t *src);
PLAYERXDR_EXPORT void player_blobfinder_color_config_t_cleanup(const player_blobfinder_color_config_t *msg);
PLAYERXDR_EXPORT player_blobfinder_color_config_t * player_blobfinder_color_config_t_clone(const player_blobfinder_color_config_t *msg);
PLAYERXDR_EXPORT void player_blobfinder_color_config_t_free(player_blobfinder_color_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_blobfinder_color_config_t_sizeof(player_blobfinder_color_config_t *msg);
int xdr_player_blobfinder_imager_config_t (XDR* xdrs, player_blobfinder_imager_config_t * msg);
PLAYERXDR_EXPORT int player_blobfinder_imager_config_pack(void* buf, size_t buflen, player_blobfinder_imager_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blobfinder_imager_config_t_copy(player_blobfinder_imager_config_t *dest, const player_blobfinder_imager_config_t *src);
PLAYERXDR_EXPORT void player_blobfinder_imager_config_t_cleanup(const player_blobfinder_imager_config_t *msg);
PLAYERXDR_EXPORT player_blobfinder_imager_config_t * player_blobfinder_imager_config_t_clone(const player_blobfinder_imager_config_t *msg);
PLAYERXDR_EXPORT void player_blobfinder_imager_config_t_free(player_blobfinder_imager_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_blobfinder_imager_config_t_sizeof(player_blobfinder_imager_config_t *msg);
int xdr_player_ptz_data_t (XDR* xdrs, player_ptz_data_t * msg);
PLAYERXDR_EXPORT int player_ptz_data_pack(void* buf, size_t buflen, player_ptz_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_data_t_copy(player_ptz_data_t *dest, const player_ptz_data_t *src);
PLAYERXDR_EXPORT void player_ptz_data_t_cleanup(const player_ptz_data_t *msg);
PLAYERXDR_EXPORT player_ptz_data_t * player_ptz_data_t_clone(const player_ptz_data_t *msg);
PLAYERXDR_EXPORT void player_ptz_data_t_free(player_ptz_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_data_t_sizeof(player_ptz_data_t *msg);
int xdr_player_ptz_cmd_t (XDR* xdrs, player_ptz_cmd_t * msg);
PLAYERXDR_EXPORT int player_ptz_cmd_pack(void* buf, size_t buflen, player_ptz_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_cmd_t_copy(player_ptz_cmd_t *dest, const player_ptz_cmd_t *src);
PLAYERXDR_EXPORT void player_ptz_cmd_t_cleanup(const player_ptz_cmd_t *msg);
PLAYERXDR_EXPORT player_ptz_cmd_t * player_ptz_cmd_t_clone(const player_ptz_cmd_t *msg);
PLAYERXDR_EXPORT void player_ptz_cmd_t_free(player_ptz_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_cmd_t_sizeof(player_ptz_cmd_t *msg);
int xdr_player_ptz_req_status_t (XDR* xdrs, player_ptz_req_status_t * msg);
PLAYERXDR_EXPORT int player_ptz_req_status_pack(void* buf, size_t buflen, player_ptz_req_status_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_req_status_t_copy(player_ptz_req_status_t *dest, const player_ptz_req_status_t *src);
PLAYERXDR_EXPORT void player_ptz_req_status_t_cleanup(const player_ptz_req_status_t *msg);
PLAYERXDR_EXPORT player_ptz_req_status_t * player_ptz_req_status_t_clone(const player_ptz_req_status_t *msg);
PLAYERXDR_EXPORT void player_ptz_req_status_t_free(player_ptz_req_status_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_req_status_t_sizeof(player_ptz_req_status_t *msg);
int xdr_player_ptz_geom_t (XDR* xdrs, player_ptz_geom_t * msg);
PLAYERXDR_EXPORT int player_ptz_geom_pack(void* buf, size_t buflen, player_ptz_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_geom_t_copy(player_ptz_geom_t *dest, const player_ptz_geom_t *src);
PLAYERXDR_EXPORT void player_ptz_geom_t_cleanup(const player_ptz_geom_t *msg);
PLAYERXDR_EXPORT player_ptz_geom_t * player_ptz_geom_t_clone(const player_ptz_geom_t *msg);
PLAYERXDR_EXPORT void player_ptz_geom_t_free(player_ptz_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_geom_t_sizeof(player_ptz_geom_t *msg);
int xdr_player_ptz_req_generic_t (XDR* xdrs, player_ptz_req_generic_t * msg);
PLAYERXDR_EXPORT int player_ptz_req_generic_pack(void* buf, size_t buflen, player_ptz_req_generic_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_req_generic_t_copy(player_ptz_req_generic_t *dest, const player_ptz_req_generic_t *src);
PLAYERXDR_EXPORT void player_ptz_req_generic_t_cleanup(const player_ptz_req_generic_t *msg);
PLAYERXDR_EXPORT player_ptz_req_generic_t * player_ptz_req_generic_t_clone(const player_ptz_req_generic_t *msg);
PLAYERXDR_EXPORT void player_ptz_req_generic_t_free(player_ptz_req_generic_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_req_generic_t_sizeof(player_ptz_req_generic_t *msg);
int xdr_player_ptz_req_control_mode_t (XDR* xdrs, player_ptz_req_control_mode_t * msg);
PLAYERXDR_EXPORT int player_ptz_req_control_mode_pack(void* buf, size_t buflen, player_ptz_req_control_mode_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ptz_req_control_mode_t_copy(player_ptz_req_control_mode_t *dest, const player_ptz_req_control_mode_t *src);
PLAYERXDR_EXPORT void player_ptz_req_control_mode_t_cleanup(const player_ptz_req_control_mode_t *msg);
PLAYERXDR_EXPORT player_ptz_req_control_mode_t * player_ptz_req_control_mode_t_clone(const player_ptz_req_control_mode_t *msg);
PLAYERXDR_EXPORT void player_ptz_req_control_mode_t_free(player_ptz_req_control_mode_t *msg);
PLAYERXDR_EXPORT unsigned int player_ptz_req_control_mode_t_sizeof(player_ptz_req_control_mode_t *msg);
int xdr_player_audio_wav_t (XDR* xdrs, player_audio_wav_t * msg);
PLAYERXDR_EXPORT int player_audio_wav_pack(void* buf, size_t buflen, player_audio_wav_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_wav_t_copy(player_audio_wav_t *dest, const player_audio_wav_t *src);
PLAYERXDR_EXPORT void player_audio_wav_t_cleanup(const player_audio_wav_t *msg);
PLAYERXDR_EXPORT player_audio_wav_t * player_audio_wav_t_clone(const player_audio_wav_t *msg);
PLAYERXDR_EXPORT void player_audio_wav_t_free(player_audio_wav_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_wav_t_sizeof(player_audio_wav_t *msg);
int xdr_player_audio_seq_item_t (XDR* xdrs, player_audio_seq_item_t * msg);
PLAYERXDR_EXPORT int player_audio_seq_item_pack(void* buf, size_t buflen, player_audio_seq_item_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_seq_item_t_copy(player_audio_seq_item_t *dest, const player_audio_seq_item_t *src);
PLAYERXDR_EXPORT void player_audio_seq_item_t_cleanup(const player_audio_seq_item_t *msg);
PLAYERXDR_EXPORT player_audio_seq_item_t * player_audio_seq_item_t_clone(const player_audio_seq_item_t *msg);
PLAYERXDR_EXPORT void player_audio_seq_item_t_free(player_audio_seq_item_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_seq_item_t_sizeof(player_audio_seq_item_t *msg);
int xdr_player_audio_seq_t (XDR* xdrs, player_audio_seq_t * msg);
PLAYERXDR_EXPORT int player_audio_seq_pack(void* buf, size_t buflen, player_audio_seq_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_seq_t_copy(player_audio_seq_t *dest, const player_audio_seq_t *src);
PLAYERXDR_EXPORT void player_audio_seq_t_cleanup(const player_audio_seq_t *msg);
PLAYERXDR_EXPORT player_audio_seq_t * player_audio_seq_t_clone(const player_audio_seq_t *msg);
PLAYERXDR_EXPORT void player_audio_seq_t_free(player_audio_seq_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_seq_t_sizeof(player_audio_seq_t *msg);
int xdr_player_audio_mixer_channel_t (XDR* xdrs, player_audio_mixer_channel_t * msg);
PLAYERXDR_EXPORT int player_audio_mixer_channel_pack(void* buf, size_t buflen, player_audio_mixer_channel_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_t_copy(player_audio_mixer_channel_t *dest, const player_audio_mixer_channel_t *src);
PLAYERXDR_EXPORT void player_audio_mixer_channel_t_cleanup(const player_audio_mixer_channel_t *msg);
PLAYERXDR_EXPORT player_audio_mixer_channel_t * player_audio_mixer_channel_t_clone(const player_audio_mixer_channel_t *msg);
PLAYERXDR_EXPORT void player_audio_mixer_channel_t_free(player_audio_mixer_channel_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_t_sizeof(player_audio_mixer_channel_t *msg);
int xdr_player_audio_mixer_channel_list_t (XDR* xdrs, player_audio_mixer_channel_list_t * msg);
PLAYERXDR_EXPORT int player_audio_mixer_channel_list_pack(void* buf, size_t buflen, player_audio_mixer_channel_list_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_list_t_copy(player_audio_mixer_channel_list_t *dest, const player_audio_mixer_channel_list_t *src);
PLAYERXDR_EXPORT void player_audio_mixer_channel_list_t_cleanup(const player_audio_mixer_channel_list_t *msg);
PLAYERXDR_EXPORT player_audio_mixer_channel_list_t * player_audio_mixer_channel_list_t_clone(const player_audio_mixer_channel_list_t *msg);
PLAYERXDR_EXPORT void player_audio_mixer_channel_list_t_free(player_audio_mixer_channel_list_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_list_t_sizeof(player_audio_mixer_channel_list_t *msg);
int xdr_player_audio_mixer_channel_detail_t (XDR* xdrs, player_audio_mixer_channel_detail_t * msg);
PLAYERXDR_EXPORT int player_audio_mixer_channel_detail_pack(void* buf, size_t buflen, player_audio_mixer_channel_detail_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_detail_t_copy(player_audio_mixer_channel_detail_t *dest, const player_audio_mixer_channel_detail_t *src);
PLAYERXDR_EXPORT void player_audio_mixer_channel_detail_t_cleanup(const player_audio_mixer_channel_detail_t *msg);
PLAYERXDR_EXPORT player_audio_mixer_channel_detail_t * player_audio_mixer_channel_detail_t_clone(const player_audio_mixer_channel_detail_t *msg);
PLAYERXDR_EXPORT void player_audio_mixer_channel_detail_t_free(player_audio_mixer_channel_detail_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_detail_t_sizeof(player_audio_mixer_channel_detail_t *msg);
int xdr_player_audio_mixer_channel_list_detail_t (XDR* xdrs, player_audio_mixer_channel_list_detail_t * msg);
PLAYERXDR_EXPORT int player_audio_mixer_channel_list_detail_pack(void* buf, size_t buflen, player_audio_mixer_channel_list_detail_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_list_detail_t_copy(player_audio_mixer_channel_list_detail_t *dest, const player_audio_mixer_channel_list_detail_t *src);
PLAYERXDR_EXPORT void player_audio_mixer_channel_list_detail_t_cleanup(const player_audio_mixer_channel_list_detail_t *msg);
PLAYERXDR_EXPORT player_audio_mixer_channel_list_detail_t * player_audio_mixer_channel_list_detail_t_clone(const player_audio_mixer_channel_list_detail_t *msg);
PLAYERXDR_EXPORT void player_audio_mixer_channel_list_detail_t_free(player_audio_mixer_channel_list_detail_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_mixer_channel_list_detail_t_sizeof(player_audio_mixer_channel_list_detail_t *msg);
int xdr_player_audio_sample_t (XDR* xdrs, player_audio_sample_t * msg);
PLAYERXDR_EXPORT int player_audio_sample_pack(void* buf, size_t buflen, player_audio_sample_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_sample_t_copy(player_audio_sample_t *dest, const player_audio_sample_t *src);
PLAYERXDR_EXPORT void player_audio_sample_t_cleanup(const player_audio_sample_t *msg);
PLAYERXDR_EXPORT player_audio_sample_t * player_audio_sample_t_clone(const player_audio_sample_t *msg);
PLAYERXDR_EXPORT void player_audio_sample_t_free(player_audio_sample_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_sample_t_sizeof(player_audio_sample_t *msg);
int xdr_player_audio_sample_item_t (XDR* xdrs, player_audio_sample_item_t * msg);
PLAYERXDR_EXPORT int player_audio_sample_item_pack(void* buf, size_t buflen, player_audio_sample_item_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_sample_item_t_copy(player_audio_sample_item_t *dest, const player_audio_sample_item_t *src);
PLAYERXDR_EXPORT void player_audio_sample_item_t_cleanup(const player_audio_sample_item_t *msg);
PLAYERXDR_EXPORT player_audio_sample_item_t * player_audio_sample_item_t_clone(const player_audio_sample_item_t *msg);
PLAYERXDR_EXPORT void player_audio_sample_item_t_free(player_audio_sample_item_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_sample_item_t_sizeof(player_audio_sample_item_t *msg);
int xdr_player_audio_sample_rec_req_t (XDR* xdrs, player_audio_sample_rec_req_t * msg);
PLAYERXDR_EXPORT int player_audio_sample_rec_req_pack(void* buf, size_t buflen, player_audio_sample_rec_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_sample_rec_req_t_copy(player_audio_sample_rec_req_t *dest, const player_audio_sample_rec_req_t *src);
PLAYERXDR_EXPORT void player_audio_sample_rec_req_t_cleanup(const player_audio_sample_rec_req_t *msg);
PLAYERXDR_EXPORT player_audio_sample_rec_req_t * player_audio_sample_rec_req_t_clone(const player_audio_sample_rec_req_t *msg);
PLAYERXDR_EXPORT void player_audio_sample_rec_req_t_free(player_audio_sample_rec_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_sample_rec_req_t_sizeof(player_audio_sample_rec_req_t *msg);
int xdr_player_audio_state_t (XDR* xdrs, player_audio_state_t * msg);
PLAYERXDR_EXPORT int player_audio_state_pack(void* buf, size_t buflen, player_audio_state_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_audio_state_t_copy(player_audio_state_t *dest, const player_audio_state_t *src);
PLAYERXDR_EXPORT void player_audio_state_t_cleanup(const player_audio_state_t *msg);
PLAYERXDR_EXPORT player_audio_state_t * player_audio_state_t_clone(const player_audio_state_t *msg);
PLAYERXDR_EXPORT void player_audio_state_t_free(player_audio_state_t *msg);
PLAYERXDR_EXPORT unsigned int player_audio_state_t_sizeof(player_audio_state_t *msg);
int xdr_player_fiducial_item_t (XDR* xdrs, player_fiducial_item_t * msg);
PLAYERXDR_EXPORT int player_fiducial_item_pack(void* buf, size_t buflen, player_fiducial_item_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_fiducial_item_t_copy(player_fiducial_item_t *dest, const player_fiducial_item_t *src);
PLAYERXDR_EXPORT void player_fiducial_item_t_cleanup(const player_fiducial_item_t *msg);
PLAYERXDR_EXPORT player_fiducial_item_t * player_fiducial_item_t_clone(const player_fiducial_item_t *msg);
PLAYERXDR_EXPORT void player_fiducial_item_t_free(player_fiducial_item_t *msg);
PLAYERXDR_EXPORT unsigned int player_fiducial_item_t_sizeof(player_fiducial_item_t *msg);
int xdr_player_fiducial_data_t (XDR* xdrs, player_fiducial_data_t * msg);
PLAYERXDR_EXPORT int player_fiducial_data_pack(void* buf, size_t buflen, player_fiducial_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_fiducial_data_t_copy(player_fiducial_data_t *dest, const player_fiducial_data_t *src);
PLAYERXDR_EXPORT void player_fiducial_data_t_cleanup(const player_fiducial_data_t *msg);
PLAYERXDR_EXPORT player_fiducial_data_t * player_fiducial_data_t_clone(const player_fiducial_data_t *msg);
PLAYERXDR_EXPORT void player_fiducial_data_t_free(player_fiducial_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_fiducial_data_t_sizeof(player_fiducial_data_t *msg);
int xdr_player_fiducial_geom_t (XDR* xdrs, player_fiducial_geom_t * msg);
PLAYERXDR_EXPORT int player_fiducial_geom_pack(void* buf, size_t buflen, player_fiducial_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_fiducial_geom_t_copy(player_fiducial_geom_t *dest, const player_fiducial_geom_t *src);
PLAYERXDR_EXPORT void player_fiducial_geom_t_cleanup(const player_fiducial_geom_t *msg);
PLAYERXDR_EXPORT player_fiducial_geom_t * player_fiducial_geom_t_clone(const player_fiducial_geom_t *msg);
PLAYERXDR_EXPORT void player_fiducial_geom_t_free(player_fiducial_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_fiducial_geom_t_sizeof(player_fiducial_geom_t *msg);
int xdr_player_fiducial_fov_t (XDR* xdrs, player_fiducial_fov_t * msg);
PLAYERXDR_EXPORT int player_fiducial_fov_pack(void* buf, size_t buflen, player_fiducial_fov_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_fiducial_fov_t_copy(player_fiducial_fov_t *dest, const player_fiducial_fov_t *src);
PLAYERXDR_EXPORT void player_fiducial_fov_t_cleanup(const player_fiducial_fov_t *msg);
PLAYERXDR_EXPORT player_fiducial_fov_t * player_fiducial_fov_t_clone(const player_fiducial_fov_t *msg);
PLAYERXDR_EXPORT void player_fiducial_fov_t_free(player_fiducial_fov_t *msg);
PLAYERXDR_EXPORT unsigned int player_fiducial_fov_t_sizeof(player_fiducial_fov_t *msg);
int xdr_player_fiducial_id_t (XDR* xdrs, player_fiducial_id_t * msg);
PLAYERXDR_EXPORT int player_fiducial_id_pack(void* buf, size_t buflen, player_fiducial_id_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_fiducial_id_t_copy(player_fiducial_id_t *dest, const player_fiducial_id_t *src);
PLAYERXDR_EXPORT void player_fiducial_id_t_cleanup(const player_fiducial_id_t *msg);
PLAYERXDR_EXPORT player_fiducial_id_t * player_fiducial_id_t_clone(const player_fiducial_id_t *msg);
PLAYERXDR_EXPORT void player_fiducial_id_t_free(player_fiducial_id_t *msg);
PLAYERXDR_EXPORT unsigned int player_fiducial_id_t_sizeof(player_fiducial_id_t *msg);
int xdr_player_speech_cmd_t (XDR* xdrs, player_speech_cmd_t * msg);
PLAYERXDR_EXPORT int player_speech_cmd_pack(void* buf, size_t buflen, player_speech_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_speech_cmd_t_copy(player_speech_cmd_t *dest, const player_speech_cmd_t *src);
PLAYERXDR_EXPORT void player_speech_cmd_t_cleanup(const player_speech_cmd_t *msg);
PLAYERXDR_EXPORT player_speech_cmd_t * player_speech_cmd_t_clone(const player_speech_cmd_t *msg);
PLAYERXDR_EXPORT void player_speech_cmd_t_free(player_speech_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_speech_cmd_t_sizeof(player_speech_cmd_t *msg);
int xdr_player_gps_data_t (XDR* xdrs, player_gps_data_t * msg);
PLAYERXDR_EXPORT int player_gps_data_pack(void* buf, size_t buflen, player_gps_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_gps_data_t_copy(player_gps_data_t *dest, const player_gps_data_t *src);
PLAYERXDR_EXPORT void player_gps_data_t_cleanup(const player_gps_data_t *msg);
PLAYERXDR_EXPORT player_gps_data_t * player_gps_data_t_clone(const player_gps_data_t *msg);
PLAYERXDR_EXPORT void player_gps_data_t_free(player_gps_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_gps_data_t_sizeof(player_gps_data_t *msg);
int xdr_player_bumper_data_t (XDR* xdrs, player_bumper_data_t * msg);
PLAYERXDR_EXPORT int player_bumper_data_pack(void* buf, size_t buflen, player_bumper_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bumper_data_t_copy(player_bumper_data_t *dest, const player_bumper_data_t *src);
PLAYERXDR_EXPORT void player_bumper_data_t_cleanup(const player_bumper_data_t *msg);
PLAYERXDR_EXPORT player_bumper_data_t * player_bumper_data_t_clone(const player_bumper_data_t *msg);
PLAYERXDR_EXPORT void player_bumper_data_t_free(player_bumper_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_bumper_data_t_sizeof(player_bumper_data_t *msg);
int xdr_player_bumper_define_t (XDR* xdrs, player_bumper_define_t * msg);
PLAYERXDR_EXPORT int player_bumper_define_pack(void* buf, size_t buflen, player_bumper_define_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bumper_define_t_copy(player_bumper_define_t *dest, const player_bumper_define_t *src);
PLAYERXDR_EXPORT void player_bumper_define_t_cleanup(const player_bumper_define_t *msg);
PLAYERXDR_EXPORT player_bumper_define_t * player_bumper_define_t_clone(const player_bumper_define_t *msg);
PLAYERXDR_EXPORT void player_bumper_define_t_free(player_bumper_define_t *msg);
PLAYERXDR_EXPORT unsigned int player_bumper_define_t_sizeof(player_bumper_define_t *msg);
int xdr_player_bumper_geom_t (XDR* xdrs, player_bumper_geom_t * msg);
PLAYERXDR_EXPORT int player_bumper_geom_pack(void* buf, size_t buflen, player_bumper_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_bumper_geom_t_copy(player_bumper_geom_t *dest, const player_bumper_geom_t *src);
PLAYERXDR_EXPORT void player_bumper_geom_t_cleanup(const player_bumper_geom_t *msg);
PLAYERXDR_EXPORT player_bumper_geom_t * player_bumper_geom_t_clone(const player_bumper_geom_t *msg);
PLAYERXDR_EXPORT void player_bumper_geom_t_free(player_bumper_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_bumper_geom_t_sizeof(player_bumper_geom_t *msg);
int xdr_player_dio_data_t (XDR* xdrs, player_dio_data_t * msg);
PLAYERXDR_EXPORT int player_dio_data_pack(void* buf, size_t buflen, player_dio_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_dio_data_t_copy(player_dio_data_t *dest, const player_dio_data_t *src);
PLAYERXDR_EXPORT void player_dio_data_t_cleanup(const player_dio_data_t *msg);
PLAYERXDR_EXPORT player_dio_data_t * player_dio_data_t_clone(const player_dio_data_t *msg);
PLAYERXDR_EXPORT void player_dio_data_t_free(player_dio_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_dio_data_t_sizeof(player_dio_data_t *msg);
int xdr_player_dio_cmd_t (XDR* xdrs, player_dio_cmd_t * msg);
PLAYERXDR_EXPORT int player_dio_cmd_pack(void* buf, size_t buflen, player_dio_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_dio_cmd_t_copy(player_dio_cmd_t *dest, const player_dio_cmd_t *src);
PLAYERXDR_EXPORT void player_dio_cmd_t_cleanup(const player_dio_cmd_t *msg);
PLAYERXDR_EXPORT player_dio_cmd_t * player_dio_cmd_t_clone(const player_dio_cmd_t *msg);
PLAYERXDR_EXPORT void player_dio_cmd_t_free(player_dio_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_dio_cmd_t_sizeof(player_dio_cmd_t *msg);
int xdr_player_aio_data_t (XDR* xdrs, player_aio_data_t * msg);
PLAYERXDR_EXPORT int player_aio_data_pack(void* buf, size_t buflen, player_aio_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_aio_data_t_copy(player_aio_data_t *dest, const player_aio_data_t *src);
PLAYERXDR_EXPORT void player_aio_data_t_cleanup(const player_aio_data_t *msg);
PLAYERXDR_EXPORT player_aio_data_t * player_aio_data_t_clone(const player_aio_data_t *msg);
PLAYERXDR_EXPORT void player_aio_data_t_free(player_aio_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_aio_data_t_sizeof(player_aio_data_t *msg);
int xdr_player_aio_cmd_t (XDR* xdrs, player_aio_cmd_t * msg);
PLAYERXDR_EXPORT int player_aio_cmd_pack(void* buf, size_t buflen, player_aio_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_aio_cmd_t_copy(player_aio_cmd_t *dest, const player_aio_cmd_t *src);
PLAYERXDR_EXPORT void player_aio_cmd_t_cleanup(const player_aio_cmd_t *msg);
PLAYERXDR_EXPORT player_aio_cmd_t * player_aio_cmd_t_clone(const player_aio_cmd_t *msg);
PLAYERXDR_EXPORT void player_aio_cmd_t_free(player_aio_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_aio_cmd_t_sizeof(player_aio_cmd_t *msg);
int xdr_player_ir_data_t (XDR* xdrs, player_ir_data_t * msg);
PLAYERXDR_EXPORT int player_ir_data_pack(void* buf, size_t buflen, player_ir_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ir_data_t_copy(player_ir_data_t *dest, const player_ir_data_t *src);
PLAYERXDR_EXPORT void player_ir_data_t_cleanup(const player_ir_data_t *msg);
PLAYERXDR_EXPORT player_ir_data_t * player_ir_data_t_clone(const player_ir_data_t *msg);
PLAYERXDR_EXPORT void player_ir_data_t_free(player_ir_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_ir_data_t_sizeof(player_ir_data_t *msg);
int xdr_player_ir_pose_t (XDR* xdrs, player_ir_pose_t * msg);
PLAYERXDR_EXPORT int player_ir_pose_pack(void* buf, size_t buflen, player_ir_pose_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ir_pose_t_copy(player_ir_pose_t *dest, const player_ir_pose_t *src);
PLAYERXDR_EXPORT void player_ir_pose_t_cleanup(const player_ir_pose_t *msg);
PLAYERXDR_EXPORT player_ir_pose_t * player_ir_pose_t_clone(const player_ir_pose_t *msg);
PLAYERXDR_EXPORT void player_ir_pose_t_free(player_ir_pose_t *msg);
PLAYERXDR_EXPORT unsigned int player_ir_pose_t_sizeof(player_ir_pose_t *msg);
int xdr_player_ir_power_req_t (XDR* xdrs, player_ir_power_req_t * msg);
PLAYERXDR_EXPORT int player_ir_power_req_pack(void* buf, size_t buflen, player_ir_power_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ir_power_req_t_copy(player_ir_power_req_t *dest, const player_ir_power_req_t *src);
PLAYERXDR_EXPORT void player_ir_power_req_t_cleanup(const player_ir_power_req_t *msg);
PLAYERXDR_EXPORT player_ir_power_req_t * player_ir_power_req_t_clone(const player_ir_power_req_t *msg);
PLAYERXDR_EXPORT void player_ir_power_req_t_free(player_ir_power_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_ir_power_req_t_sizeof(player_ir_power_req_t *msg);
int xdr_player_wifi_link_t (XDR* xdrs, player_wifi_link_t * msg);
PLAYERXDR_EXPORT int player_wifi_link_pack(void* buf, size_t buflen, player_wifi_link_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wifi_link_t_copy(player_wifi_link_t *dest, const player_wifi_link_t *src);
PLAYERXDR_EXPORT void player_wifi_link_t_cleanup(const player_wifi_link_t *msg);
PLAYERXDR_EXPORT player_wifi_link_t * player_wifi_link_t_clone(const player_wifi_link_t *msg);
PLAYERXDR_EXPORT void player_wifi_link_t_free(player_wifi_link_t *msg);
PLAYERXDR_EXPORT unsigned int player_wifi_link_t_sizeof(player_wifi_link_t *msg);
int xdr_player_wifi_data_t (XDR* xdrs, player_wifi_data_t * msg);
PLAYERXDR_EXPORT int player_wifi_data_pack(void* buf, size_t buflen, player_wifi_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wifi_data_t_copy(player_wifi_data_t *dest, const player_wifi_data_t *src);
PLAYERXDR_EXPORT void player_wifi_data_t_cleanup(const player_wifi_data_t *msg);
PLAYERXDR_EXPORT player_wifi_data_t * player_wifi_data_t_clone(const player_wifi_data_t *msg);
PLAYERXDR_EXPORT void player_wifi_data_t_free(player_wifi_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_wifi_data_t_sizeof(player_wifi_data_t *msg);
int xdr_player_wifi_mac_req_t (XDR* xdrs, player_wifi_mac_req_t * msg);
PLAYERXDR_EXPORT int player_wifi_mac_req_pack(void* buf, size_t buflen, player_wifi_mac_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wifi_mac_req_t_copy(player_wifi_mac_req_t *dest, const player_wifi_mac_req_t *src);
PLAYERXDR_EXPORT void player_wifi_mac_req_t_cleanup(const player_wifi_mac_req_t *msg);
PLAYERXDR_EXPORT player_wifi_mac_req_t * player_wifi_mac_req_t_clone(const player_wifi_mac_req_t *msg);
PLAYERXDR_EXPORT void player_wifi_mac_req_t_free(player_wifi_mac_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_wifi_mac_req_t_sizeof(player_wifi_mac_req_t *msg);
int xdr_player_wifi_iwspy_addr_req_t (XDR* xdrs, player_wifi_iwspy_addr_req_t * msg);
PLAYERXDR_EXPORT int player_wifi_iwspy_addr_req_pack(void* buf, size_t buflen, player_wifi_iwspy_addr_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wifi_iwspy_addr_req_t_copy(player_wifi_iwspy_addr_req_t *dest, const player_wifi_iwspy_addr_req_t *src);
PLAYERXDR_EXPORT void player_wifi_iwspy_addr_req_t_cleanup(const player_wifi_iwspy_addr_req_t *msg);
PLAYERXDR_EXPORT player_wifi_iwspy_addr_req_t * player_wifi_iwspy_addr_req_t_clone(const player_wifi_iwspy_addr_req_t *msg);
PLAYERXDR_EXPORT void player_wifi_iwspy_addr_req_t_free(player_wifi_iwspy_addr_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_wifi_iwspy_addr_req_t_sizeof(player_wifi_iwspy_addr_req_t *msg);
int xdr_player_localize_hypoth_t (XDR* xdrs, player_localize_hypoth_t * msg);
PLAYERXDR_EXPORT int player_localize_hypoth_pack(void* buf, size_t buflen, player_localize_hypoth_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_localize_hypoth_t_copy(player_localize_hypoth_t *dest, const player_localize_hypoth_t *src);
PLAYERXDR_EXPORT void player_localize_hypoth_t_cleanup(const player_localize_hypoth_t *msg);
PLAYERXDR_EXPORT player_localize_hypoth_t * player_localize_hypoth_t_clone(const player_localize_hypoth_t *msg);
PLAYERXDR_EXPORT void player_localize_hypoth_t_free(player_localize_hypoth_t *msg);
PLAYERXDR_EXPORT unsigned int player_localize_hypoth_t_sizeof(player_localize_hypoth_t *msg);
int xdr_player_localize_data_t (XDR* xdrs, player_localize_data_t * msg);
PLAYERXDR_EXPORT int player_localize_data_pack(void* buf, size_t buflen, player_localize_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_localize_data_t_copy(player_localize_data_t *dest, const player_localize_data_t *src);
PLAYERXDR_EXPORT void player_localize_data_t_cleanup(const player_localize_data_t *msg);
PLAYERXDR_EXPORT player_localize_data_t * player_localize_data_t_clone(const player_localize_data_t *msg);
PLAYERXDR_EXPORT void player_localize_data_t_free(player_localize_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_localize_data_t_sizeof(player_localize_data_t *msg);
int xdr_player_localize_set_pose_t (XDR* xdrs, player_localize_set_pose_t * msg);
PLAYERXDR_EXPORT int player_localize_set_pose_pack(void* buf, size_t buflen, player_localize_set_pose_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_localize_set_pose_t_copy(player_localize_set_pose_t *dest, const player_localize_set_pose_t *src);
PLAYERXDR_EXPORT void player_localize_set_pose_t_cleanup(const player_localize_set_pose_t *msg);
PLAYERXDR_EXPORT player_localize_set_pose_t * player_localize_set_pose_t_clone(const player_localize_set_pose_t *msg);
PLAYERXDR_EXPORT void player_localize_set_pose_t_free(player_localize_set_pose_t *msg);
PLAYERXDR_EXPORT unsigned int player_localize_set_pose_t_sizeof(player_localize_set_pose_t *msg);
int xdr_player_localize_particle_t (XDR* xdrs, player_localize_particle_t * msg);
PLAYERXDR_EXPORT int player_localize_particle_pack(void* buf, size_t buflen, player_localize_particle_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_localize_particle_t_copy(player_localize_particle_t *dest, const player_localize_particle_t *src);
PLAYERXDR_EXPORT void player_localize_particle_t_cleanup(const player_localize_particle_t *msg);
PLAYERXDR_EXPORT player_localize_particle_t * player_localize_particle_t_clone(const player_localize_particle_t *msg);
PLAYERXDR_EXPORT void player_localize_particle_t_free(player_localize_particle_t *msg);
PLAYERXDR_EXPORT unsigned int player_localize_particle_t_sizeof(player_localize_particle_t *msg);
int xdr_player_localize_get_particles_t (XDR* xdrs, player_localize_get_particles_t * msg);
PLAYERXDR_EXPORT int player_localize_get_particles_pack(void* buf, size_t buflen, player_localize_get_particles_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_localize_get_particles_t_copy(player_localize_get_particles_t *dest, const player_localize_get_particles_t *src);
PLAYERXDR_EXPORT void player_localize_get_particles_t_cleanup(const player_localize_get_particles_t *msg);
PLAYERXDR_EXPORT player_localize_get_particles_t * player_localize_get_particles_t_clone(const player_localize_get_particles_t *msg);
PLAYERXDR_EXPORT void player_localize_get_particles_t_free(player_localize_get_particles_t *msg);
PLAYERXDR_EXPORT unsigned int player_localize_get_particles_t_sizeof(player_localize_get_particles_t *msg);
int xdr_player_position3d_data_t (XDR* xdrs, player_position3d_data_t * msg);
PLAYERXDR_EXPORT int player_position3d_data_pack(void* buf, size_t buflen, player_position3d_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_data_t_copy(player_position3d_data_t *dest, const player_position3d_data_t *src);
PLAYERXDR_EXPORT void player_position3d_data_t_cleanup(const player_position3d_data_t *msg);
PLAYERXDR_EXPORT player_position3d_data_t * player_position3d_data_t_clone(const player_position3d_data_t *msg);
PLAYERXDR_EXPORT void player_position3d_data_t_free(player_position3d_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_data_t_sizeof(player_position3d_data_t *msg);
int xdr_player_position3d_cmd_pos_t (XDR* xdrs, player_position3d_cmd_pos_t * msg);
PLAYERXDR_EXPORT int player_position3d_cmd_pos_pack(void* buf, size_t buflen, player_position3d_cmd_pos_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_cmd_pos_t_copy(player_position3d_cmd_pos_t *dest, const player_position3d_cmd_pos_t *src);
PLAYERXDR_EXPORT void player_position3d_cmd_pos_t_cleanup(const player_position3d_cmd_pos_t *msg);
PLAYERXDR_EXPORT player_position3d_cmd_pos_t * player_position3d_cmd_pos_t_clone(const player_position3d_cmd_pos_t *msg);
PLAYERXDR_EXPORT void player_position3d_cmd_pos_t_free(player_position3d_cmd_pos_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_cmd_pos_t_sizeof(player_position3d_cmd_pos_t *msg);
int xdr_player_position3d_cmd_vel_t (XDR* xdrs, player_position3d_cmd_vel_t * msg);
PLAYERXDR_EXPORT int player_position3d_cmd_vel_pack(void* buf, size_t buflen, player_position3d_cmd_vel_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_cmd_vel_t_copy(player_position3d_cmd_vel_t *dest, const player_position3d_cmd_vel_t *src);
PLAYERXDR_EXPORT void player_position3d_cmd_vel_t_cleanup(const player_position3d_cmd_vel_t *msg);
PLAYERXDR_EXPORT player_position3d_cmd_vel_t * player_position3d_cmd_vel_t_clone(const player_position3d_cmd_vel_t *msg);
PLAYERXDR_EXPORT void player_position3d_cmd_vel_t_free(player_position3d_cmd_vel_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_cmd_vel_t_sizeof(player_position3d_cmd_vel_t *msg);
int xdr_player_position3d_geom_t (XDR* xdrs, player_position3d_geom_t * msg);
PLAYERXDR_EXPORT int player_position3d_geom_pack(void* buf, size_t buflen, player_position3d_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_geom_t_copy(player_position3d_geom_t *dest, const player_position3d_geom_t *src);
PLAYERXDR_EXPORT void player_position3d_geom_t_cleanup(const player_position3d_geom_t *msg);
PLAYERXDR_EXPORT player_position3d_geom_t * player_position3d_geom_t_clone(const player_position3d_geom_t *msg);
PLAYERXDR_EXPORT void player_position3d_geom_t_free(player_position3d_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_geom_t_sizeof(player_position3d_geom_t *msg);
int xdr_player_position3d_power_config_t (XDR* xdrs, player_position3d_power_config_t * msg);
PLAYERXDR_EXPORT int player_position3d_power_config_pack(void* buf, size_t buflen, player_position3d_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_power_config_t_copy(player_position3d_power_config_t *dest, const player_position3d_power_config_t *src);
PLAYERXDR_EXPORT void player_position3d_power_config_t_cleanup(const player_position3d_power_config_t *msg);
PLAYERXDR_EXPORT player_position3d_power_config_t * player_position3d_power_config_t_clone(const player_position3d_power_config_t *msg);
PLAYERXDR_EXPORT void player_position3d_power_config_t_free(player_position3d_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_power_config_t_sizeof(player_position3d_power_config_t *msg);
int xdr_player_position3d_position_mode_req_t (XDR* xdrs, player_position3d_position_mode_req_t * msg);
PLAYERXDR_EXPORT int player_position3d_position_mode_req_pack(void* buf, size_t buflen, player_position3d_position_mode_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_position_mode_req_t_copy(player_position3d_position_mode_req_t *dest, const player_position3d_position_mode_req_t *src);
PLAYERXDR_EXPORT void player_position3d_position_mode_req_t_cleanup(const player_position3d_position_mode_req_t *msg);
PLAYERXDR_EXPORT player_position3d_position_mode_req_t * player_position3d_position_mode_req_t_clone(const player_position3d_position_mode_req_t *msg);
PLAYERXDR_EXPORT void player_position3d_position_mode_req_t_free(player_position3d_position_mode_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_position_mode_req_t_sizeof(player_position3d_position_mode_req_t *msg);
int xdr_player_position3d_velocity_mode_config_t (XDR* xdrs, player_position3d_velocity_mode_config_t * msg);
PLAYERXDR_EXPORT int player_position3d_velocity_mode_config_pack(void* buf, size_t buflen, player_position3d_velocity_mode_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_velocity_mode_config_t_copy(player_position3d_velocity_mode_config_t *dest, const player_position3d_velocity_mode_config_t *src);
PLAYERXDR_EXPORT void player_position3d_velocity_mode_config_t_cleanup(const player_position3d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT player_position3d_velocity_mode_config_t * player_position3d_velocity_mode_config_t_clone(const player_position3d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT void player_position3d_velocity_mode_config_t_free(player_position3d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_velocity_mode_config_t_sizeof(player_position3d_velocity_mode_config_t *msg);
int xdr_player_position3d_set_odom_req_t (XDR* xdrs, player_position3d_set_odom_req_t * msg);
PLAYERXDR_EXPORT int player_position3d_set_odom_req_pack(void* buf, size_t buflen, player_position3d_set_odom_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_set_odom_req_t_copy(player_position3d_set_odom_req_t *dest, const player_position3d_set_odom_req_t *src);
PLAYERXDR_EXPORT void player_position3d_set_odom_req_t_cleanup(const player_position3d_set_odom_req_t *msg);
PLAYERXDR_EXPORT player_position3d_set_odom_req_t * player_position3d_set_odom_req_t_clone(const player_position3d_set_odom_req_t *msg);
PLAYERXDR_EXPORT void player_position3d_set_odom_req_t_free(player_position3d_set_odom_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_set_odom_req_t_sizeof(player_position3d_set_odom_req_t *msg);
int xdr_player_position3d_speed_pid_req_t (XDR* xdrs, player_position3d_speed_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position3d_speed_pid_req_pack(void* buf, size_t buflen, player_position3d_speed_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_speed_pid_req_t_copy(player_position3d_speed_pid_req_t *dest, const player_position3d_speed_pid_req_t *src);
PLAYERXDR_EXPORT void player_position3d_speed_pid_req_t_cleanup(const player_position3d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT player_position3d_speed_pid_req_t * player_position3d_speed_pid_req_t_clone(const player_position3d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position3d_speed_pid_req_t_free(player_position3d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_speed_pid_req_t_sizeof(player_position3d_speed_pid_req_t *msg);
int xdr_player_position3d_position_pid_req_t (XDR* xdrs, player_position3d_position_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position3d_position_pid_req_pack(void* buf, size_t buflen, player_position3d_position_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_position_pid_req_t_copy(player_position3d_position_pid_req_t *dest, const player_position3d_position_pid_req_t *src);
PLAYERXDR_EXPORT void player_position3d_position_pid_req_t_cleanup(const player_position3d_position_pid_req_t *msg);
PLAYERXDR_EXPORT player_position3d_position_pid_req_t * player_position3d_position_pid_req_t_clone(const player_position3d_position_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position3d_position_pid_req_t_free(player_position3d_position_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_position_pid_req_t_sizeof(player_position3d_position_pid_req_t *msg);
int xdr_player_position3d_speed_prof_req_t (XDR* xdrs, player_position3d_speed_prof_req_t * msg);
PLAYERXDR_EXPORT int player_position3d_speed_prof_req_pack(void* buf, size_t buflen, player_position3d_speed_prof_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position3d_speed_prof_req_t_copy(player_position3d_speed_prof_req_t *dest, const player_position3d_speed_prof_req_t *src);
PLAYERXDR_EXPORT void player_position3d_speed_prof_req_t_cleanup(const player_position3d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT player_position3d_speed_prof_req_t * player_position3d_speed_prof_req_t_clone(const player_position3d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT void player_position3d_speed_prof_req_t_free(player_position3d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position3d_speed_prof_req_t_sizeof(player_position3d_speed_prof_req_t *msg);
int xdr_player_simulation_data_t (XDR* xdrs, player_simulation_data_t * msg);
PLAYERXDR_EXPORT int player_simulation_data_pack(void* buf, size_t buflen, player_simulation_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_simulation_data_t_copy(player_simulation_data_t *dest, const player_simulation_data_t *src);
PLAYERXDR_EXPORT void player_simulation_data_t_cleanup(const player_simulation_data_t *msg);
PLAYERXDR_EXPORT player_simulation_data_t * player_simulation_data_t_clone(const player_simulation_data_t *msg);
PLAYERXDR_EXPORT void player_simulation_data_t_free(player_simulation_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_simulation_data_t_sizeof(player_simulation_data_t *msg);
int xdr_player_simulation_cmd_t (XDR* xdrs, player_simulation_cmd_t * msg);
PLAYERXDR_EXPORT int player_simulation_cmd_pack(void* buf, size_t buflen, player_simulation_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_simulation_cmd_t_copy(player_simulation_cmd_t *dest, const player_simulation_cmd_t *src);
PLAYERXDR_EXPORT void player_simulation_cmd_t_cleanup(const player_simulation_cmd_t *msg);
PLAYERXDR_EXPORT player_simulation_cmd_t * player_simulation_cmd_t_clone(const player_simulation_cmd_t *msg);
PLAYERXDR_EXPORT void player_simulation_cmd_t_free(player_simulation_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_simulation_cmd_t_sizeof(player_simulation_cmd_t *msg);
int xdr_player_simulation_pose2d_req_t (XDR* xdrs, player_simulation_pose2d_req_t * msg);
PLAYERXDR_EXPORT int player_simulation_pose2d_req_pack(void* buf, size_t buflen, player_simulation_pose2d_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_simulation_pose2d_req_t_copy(player_simulation_pose2d_req_t *dest, const player_simulation_pose2d_req_t *src);
PLAYERXDR_EXPORT void player_simulation_pose2d_req_t_cleanup(const player_simulation_pose2d_req_t *msg);
PLAYERXDR_EXPORT player_simulation_pose2d_req_t * player_simulation_pose2d_req_t_clone(const player_simulation_pose2d_req_t *msg);
PLAYERXDR_EXPORT void player_simulation_pose2d_req_t_free(player_simulation_pose2d_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_simulation_pose2d_req_t_sizeof(player_simulation_pose2d_req_t *msg);
int xdr_player_simulation_pose3d_req_t (XDR* xdrs, player_simulation_pose3d_req_t * msg);
PLAYERXDR_EXPORT int player_simulation_pose3d_req_pack(void* buf, size_t buflen, player_simulation_pose3d_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_simulation_pose3d_req_t_copy(player_simulation_pose3d_req_t *dest, const player_simulation_pose3d_req_t *src);
PLAYERXDR_EXPORT void player_simulation_pose3d_req_t_cleanup(const player_simulation_pose3d_req_t *msg);
PLAYERXDR_EXPORT player_simulation_pose3d_req_t * player_simulation_pose3d_req_t_clone(const player_simulation_pose3d_req_t *msg);
PLAYERXDR_EXPORT void player_simulation_pose3d_req_t_free(player_simulation_pose3d_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_simulation_pose3d_req_t_sizeof(player_simulation_pose3d_req_t *msg);
int xdr_player_simulation_property_req_t (XDR* xdrs, player_simulation_property_req_t * msg);
PLAYERXDR_EXPORT int player_simulation_property_req_pack(void* buf, size_t buflen, player_simulation_property_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_simulation_property_req_t_copy(player_simulation_property_req_t *dest, const player_simulation_property_req_t *src);
PLAYERXDR_EXPORT void player_simulation_property_req_t_cleanup(const player_simulation_property_req_t *msg);
PLAYERXDR_EXPORT player_simulation_property_req_t * player_simulation_property_req_t_clone(const player_simulation_property_req_t *msg);
PLAYERXDR_EXPORT void player_simulation_property_req_t_free(player_simulation_property_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_simulation_property_req_t_sizeof(player_simulation_property_req_t *msg);
int xdr_player_blinkenlight_data_t (XDR* xdrs, player_blinkenlight_data_t * msg);
PLAYERXDR_EXPORT int player_blinkenlight_data_pack(void* buf, size_t buflen, player_blinkenlight_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_data_t_copy(player_blinkenlight_data_t *dest, const player_blinkenlight_data_t *src);
PLAYERXDR_EXPORT void player_blinkenlight_data_t_cleanup(const player_blinkenlight_data_t *msg);
PLAYERXDR_EXPORT player_blinkenlight_data_t * player_blinkenlight_data_t_clone(const player_blinkenlight_data_t *msg);
PLAYERXDR_EXPORT void player_blinkenlight_data_t_free(player_blinkenlight_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_data_t_sizeof(player_blinkenlight_data_t *msg);
int xdr_player_blinkenlight_cmd_t (XDR* xdrs, player_blinkenlight_cmd_t * msg);
PLAYERXDR_EXPORT int player_blinkenlight_cmd_pack(void* buf, size_t buflen, player_blinkenlight_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_t_copy(player_blinkenlight_cmd_t *dest, const player_blinkenlight_cmd_t *src);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_t_cleanup(const player_blinkenlight_cmd_t *msg);
PLAYERXDR_EXPORT player_blinkenlight_cmd_t * player_blinkenlight_cmd_t_clone(const player_blinkenlight_cmd_t *msg);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_t_free(player_blinkenlight_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_t_sizeof(player_blinkenlight_cmd_t *msg);
int xdr_player_blinkenlight_cmd_power_t (XDR* xdrs, player_blinkenlight_cmd_power_t * msg);
PLAYERXDR_EXPORT int player_blinkenlight_cmd_power_pack(void* buf, size_t buflen, player_blinkenlight_cmd_power_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_power_t_copy(player_blinkenlight_cmd_power_t *dest, const player_blinkenlight_cmd_power_t *src);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_power_t_cleanup(const player_blinkenlight_cmd_power_t *msg);
PLAYERXDR_EXPORT player_blinkenlight_cmd_power_t * player_blinkenlight_cmd_power_t_clone(const player_blinkenlight_cmd_power_t *msg);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_power_t_free(player_blinkenlight_cmd_power_t *msg);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_power_t_sizeof(player_blinkenlight_cmd_power_t *msg);
int xdr_player_blinkenlight_cmd_color_t (XDR* xdrs, player_blinkenlight_cmd_color_t * msg);
PLAYERXDR_EXPORT int player_blinkenlight_cmd_color_pack(void* buf, size_t buflen, player_blinkenlight_cmd_color_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_color_t_copy(player_blinkenlight_cmd_color_t *dest, const player_blinkenlight_cmd_color_t *src);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_color_t_cleanup(const player_blinkenlight_cmd_color_t *msg);
PLAYERXDR_EXPORT player_blinkenlight_cmd_color_t * player_blinkenlight_cmd_color_t_clone(const player_blinkenlight_cmd_color_t *msg);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_color_t_free(player_blinkenlight_cmd_color_t *msg);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_color_t_sizeof(player_blinkenlight_cmd_color_t *msg);
int xdr_player_blinkenlight_cmd_flash_t (XDR* xdrs, player_blinkenlight_cmd_flash_t * msg);
PLAYERXDR_EXPORT int player_blinkenlight_cmd_flash_pack(void* buf, size_t buflen, player_blinkenlight_cmd_flash_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_flash_t_copy(player_blinkenlight_cmd_flash_t *dest, const player_blinkenlight_cmd_flash_t *src);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_flash_t_cleanup(const player_blinkenlight_cmd_flash_t *msg);
PLAYERXDR_EXPORT player_blinkenlight_cmd_flash_t * player_blinkenlight_cmd_flash_t_clone(const player_blinkenlight_cmd_flash_t *msg);
PLAYERXDR_EXPORT void player_blinkenlight_cmd_flash_t_free(player_blinkenlight_cmd_flash_t *msg);
PLAYERXDR_EXPORT unsigned int player_blinkenlight_cmd_flash_t_sizeof(player_blinkenlight_cmd_flash_t *msg);
int xdr_player_camera_data_t (XDR* xdrs, player_camera_data_t * msg);
PLAYERXDR_EXPORT int player_camera_data_pack(void* buf, size_t buflen, player_camera_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_camera_data_t_copy(player_camera_data_t *dest, const player_camera_data_t *src);
PLAYERXDR_EXPORT void player_camera_data_t_cleanup(const player_camera_data_t *msg);
PLAYERXDR_EXPORT player_camera_data_t * player_camera_data_t_clone(const player_camera_data_t *msg);
PLAYERXDR_EXPORT void player_camera_data_t_free(player_camera_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_camera_data_t_sizeof(player_camera_data_t *msg);
int xdr_player_camera_source_t (XDR* xdrs, player_camera_source_t * msg);
PLAYERXDR_EXPORT int player_camera_source_pack(void* buf, size_t buflen, player_camera_source_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_camera_source_t_copy(player_camera_source_t *dest, const player_camera_source_t *src);
PLAYERXDR_EXPORT void player_camera_source_t_cleanup(const player_camera_source_t *msg);
PLAYERXDR_EXPORT player_camera_source_t * player_camera_source_t_clone(const player_camera_source_t *msg);
PLAYERXDR_EXPORT void player_camera_source_t_free(player_camera_source_t *msg);
PLAYERXDR_EXPORT unsigned int player_camera_source_t_sizeof(player_camera_source_t *msg);
int xdr_player_map_info_t (XDR* xdrs, player_map_info_t * msg);
PLAYERXDR_EXPORT int player_map_info_pack(void* buf, size_t buflen, player_map_info_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_map_info_t_copy(player_map_info_t *dest, const player_map_info_t *src);
PLAYERXDR_EXPORT void player_map_info_t_cleanup(const player_map_info_t *msg);
PLAYERXDR_EXPORT player_map_info_t * player_map_info_t_clone(const player_map_info_t *msg);
PLAYERXDR_EXPORT void player_map_info_t_free(player_map_info_t *msg);
PLAYERXDR_EXPORT unsigned int player_map_info_t_sizeof(player_map_info_t *msg);
int xdr_player_map_data_t (XDR* xdrs, player_map_data_t * msg);
PLAYERXDR_EXPORT int player_map_data_pack(void* buf, size_t buflen, player_map_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_map_data_t_copy(player_map_data_t *dest, const player_map_data_t *src);
PLAYERXDR_EXPORT void player_map_data_t_cleanup(const player_map_data_t *msg);
PLAYERXDR_EXPORT player_map_data_t * player_map_data_t_clone(const player_map_data_t *msg);
PLAYERXDR_EXPORT void player_map_data_t_free(player_map_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_map_data_t_sizeof(player_map_data_t *msg);
int xdr_player_map_data_vector_t (XDR* xdrs, player_map_data_vector_t * msg);
PLAYERXDR_EXPORT int player_map_data_vector_pack(void* buf, size_t buflen, player_map_data_vector_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_map_data_vector_t_copy(player_map_data_vector_t *dest, const player_map_data_vector_t *src);
PLAYERXDR_EXPORT void player_map_data_vector_t_cleanup(const player_map_data_vector_t *msg);
PLAYERXDR_EXPORT player_map_data_vector_t * player_map_data_vector_t_clone(const player_map_data_vector_t *msg);
PLAYERXDR_EXPORT void player_map_data_vector_t_free(player_map_data_vector_t *msg);
PLAYERXDR_EXPORT unsigned int player_map_data_vector_t_sizeof(player_map_data_vector_t *msg);
int xdr_player_planner_data_t (XDR* xdrs, player_planner_data_t * msg);
PLAYERXDR_EXPORT int player_planner_data_pack(void* buf, size_t buflen, player_planner_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_planner_data_t_copy(player_planner_data_t *dest, const player_planner_data_t *src);
PLAYERXDR_EXPORT void player_planner_data_t_cleanup(const player_planner_data_t *msg);
PLAYERXDR_EXPORT player_planner_data_t * player_planner_data_t_clone(const player_planner_data_t *msg);
PLAYERXDR_EXPORT void player_planner_data_t_free(player_planner_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_planner_data_t_sizeof(player_planner_data_t *msg);
int xdr_player_planner_cmd_t (XDR* xdrs, player_planner_cmd_t * msg);
PLAYERXDR_EXPORT int player_planner_cmd_pack(void* buf, size_t buflen, player_planner_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_planner_cmd_t_copy(player_planner_cmd_t *dest, const player_planner_cmd_t *src);
PLAYERXDR_EXPORT void player_planner_cmd_t_cleanup(const player_planner_cmd_t *msg);
PLAYERXDR_EXPORT player_planner_cmd_t * player_planner_cmd_t_clone(const player_planner_cmd_t *msg);
PLAYERXDR_EXPORT void player_planner_cmd_t_free(player_planner_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_planner_cmd_t_sizeof(player_planner_cmd_t *msg);
int xdr_player_planner_waypoints_req_t (XDR* xdrs, player_planner_waypoints_req_t * msg);
PLAYERXDR_EXPORT int player_planner_waypoints_req_pack(void* buf, size_t buflen, player_planner_waypoints_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_planner_waypoints_req_t_copy(player_planner_waypoints_req_t *dest, const player_planner_waypoints_req_t *src);
PLAYERXDR_EXPORT void player_planner_waypoints_req_t_cleanup(const player_planner_waypoints_req_t *msg);
PLAYERXDR_EXPORT player_planner_waypoints_req_t * player_planner_waypoints_req_t_clone(const player_planner_waypoints_req_t *msg);
PLAYERXDR_EXPORT void player_planner_waypoints_req_t_free(player_planner_waypoints_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_planner_waypoints_req_t_sizeof(player_planner_waypoints_req_t *msg);
int xdr_player_planner_enable_req_t (XDR* xdrs, player_planner_enable_req_t * msg);
PLAYERXDR_EXPORT int player_planner_enable_req_pack(void* buf, size_t buflen, player_planner_enable_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_planner_enable_req_t_copy(player_planner_enable_req_t *dest, const player_planner_enable_req_t *src);
PLAYERXDR_EXPORT void player_planner_enable_req_t_cleanup(const player_planner_enable_req_t *msg);
PLAYERXDR_EXPORT player_planner_enable_req_t * player_planner_enable_req_t_clone(const player_planner_enable_req_t *msg);
PLAYERXDR_EXPORT void player_planner_enable_req_t_free(player_planner_enable_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_planner_enable_req_t_sizeof(player_planner_enable_req_t *msg);
int xdr_player_log_set_write_state_t (XDR* xdrs, player_log_set_write_state_t * msg);
PLAYERXDR_EXPORT int player_log_set_write_state_pack(void* buf, size_t buflen, player_log_set_write_state_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_log_set_write_state_t_copy(player_log_set_write_state_t *dest, const player_log_set_write_state_t *src);
PLAYERXDR_EXPORT void player_log_set_write_state_t_cleanup(const player_log_set_write_state_t *msg);
PLAYERXDR_EXPORT player_log_set_write_state_t * player_log_set_write_state_t_clone(const player_log_set_write_state_t *msg);
PLAYERXDR_EXPORT void player_log_set_write_state_t_free(player_log_set_write_state_t *msg);
PLAYERXDR_EXPORT unsigned int player_log_set_write_state_t_sizeof(player_log_set_write_state_t *msg);
int xdr_player_log_set_read_state_t (XDR* xdrs, player_log_set_read_state_t * msg);
PLAYERXDR_EXPORT int player_log_set_read_state_pack(void* buf, size_t buflen, player_log_set_read_state_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_log_set_read_state_t_copy(player_log_set_read_state_t *dest, const player_log_set_read_state_t *src);
PLAYERXDR_EXPORT void player_log_set_read_state_t_cleanup(const player_log_set_read_state_t *msg);
PLAYERXDR_EXPORT player_log_set_read_state_t * player_log_set_read_state_t_clone(const player_log_set_read_state_t *msg);
PLAYERXDR_EXPORT void player_log_set_read_state_t_free(player_log_set_read_state_t *msg);
PLAYERXDR_EXPORT unsigned int player_log_set_read_state_t_sizeof(player_log_set_read_state_t *msg);
int xdr_player_log_get_state_t (XDR* xdrs, player_log_get_state_t * msg);
PLAYERXDR_EXPORT int player_log_get_state_pack(void* buf, size_t buflen, player_log_get_state_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_log_get_state_t_copy(player_log_get_state_t *dest, const player_log_get_state_t *src);
PLAYERXDR_EXPORT void player_log_get_state_t_cleanup(const player_log_get_state_t *msg);
PLAYERXDR_EXPORT player_log_get_state_t * player_log_get_state_t_clone(const player_log_get_state_t *msg);
PLAYERXDR_EXPORT void player_log_get_state_t_free(player_log_get_state_t *msg);
PLAYERXDR_EXPORT unsigned int player_log_get_state_t_sizeof(player_log_get_state_t *msg);
int xdr_player_log_set_filename_t (XDR* xdrs, player_log_set_filename_t * msg);
PLAYERXDR_EXPORT int player_log_set_filename_pack(void* buf, size_t buflen, player_log_set_filename_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_log_set_filename_t_copy(player_log_set_filename_t *dest, const player_log_set_filename_t *src);
PLAYERXDR_EXPORT void player_log_set_filename_t_cleanup(const player_log_set_filename_t *msg);
PLAYERXDR_EXPORT player_log_set_filename_t * player_log_set_filename_t_clone(const player_log_set_filename_t *msg);
PLAYERXDR_EXPORT void player_log_set_filename_t_free(player_log_set_filename_t *msg);
PLAYERXDR_EXPORT unsigned int player_log_set_filename_t_sizeof(player_log_set_filename_t *msg);
int xdr_player_joystick_data_t (XDR* xdrs, player_joystick_data_t * msg);
PLAYERXDR_EXPORT int player_joystick_data_pack(void* buf, size_t buflen, player_joystick_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_joystick_data_t_copy(player_joystick_data_t *dest, const player_joystick_data_t *src);
PLAYERXDR_EXPORT void player_joystick_data_t_cleanup(const player_joystick_data_t *msg);
PLAYERXDR_EXPORT player_joystick_data_t * player_joystick_data_t_clone(const player_joystick_data_t *msg);
PLAYERXDR_EXPORT void player_joystick_data_t_free(player_joystick_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_joystick_data_t_sizeof(player_joystick_data_t *msg);
int xdr_player_speech_recognition_data_t (XDR* xdrs, player_speech_recognition_data_t * msg);
PLAYERXDR_EXPORT int player_speech_recognition_data_pack(void* buf, size_t buflen, player_speech_recognition_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_speech_recognition_data_t_copy(player_speech_recognition_data_t *dest, const player_speech_recognition_data_t *src);
PLAYERXDR_EXPORT void player_speech_recognition_data_t_cleanup(const player_speech_recognition_data_t *msg);
PLAYERXDR_EXPORT player_speech_recognition_data_t * player_speech_recognition_data_t_clone(const player_speech_recognition_data_t *msg);
PLAYERXDR_EXPORT void player_speech_recognition_data_t_free(player_speech_recognition_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_speech_recognition_data_t_sizeof(player_speech_recognition_data_t *msg);
int xdr_player_opaque_data_t (XDR* xdrs, player_opaque_data_t * msg);
PLAYERXDR_EXPORT int player_opaque_data_pack(void* buf, size_t buflen, player_opaque_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_opaque_data_t_copy(player_opaque_data_t *dest, const player_opaque_data_t *src);
PLAYERXDR_EXPORT void player_opaque_data_t_cleanup(const player_opaque_data_t *msg);
PLAYERXDR_EXPORT player_opaque_data_t * player_opaque_data_t_clone(const player_opaque_data_t *msg);
PLAYERXDR_EXPORT void player_opaque_data_t_free(player_opaque_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_opaque_data_t_sizeof(player_opaque_data_t *msg);
int xdr_player_position1d_data_t (XDR* xdrs, player_position1d_data_t * msg);
PLAYERXDR_EXPORT int player_position1d_data_pack(void* buf, size_t buflen, player_position1d_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_data_t_copy(player_position1d_data_t *dest, const player_position1d_data_t *src);
PLAYERXDR_EXPORT void player_position1d_data_t_cleanup(const player_position1d_data_t *msg);
PLAYERXDR_EXPORT player_position1d_data_t * player_position1d_data_t_clone(const player_position1d_data_t *msg);
PLAYERXDR_EXPORT void player_position1d_data_t_free(player_position1d_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_data_t_sizeof(player_position1d_data_t *msg);
int xdr_player_position1d_cmd_vel_t (XDR* xdrs, player_position1d_cmd_vel_t * msg);
PLAYERXDR_EXPORT int player_position1d_cmd_vel_pack(void* buf, size_t buflen, player_position1d_cmd_vel_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_cmd_vel_t_copy(player_position1d_cmd_vel_t *dest, const player_position1d_cmd_vel_t *src);
PLAYERXDR_EXPORT void player_position1d_cmd_vel_t_cleanup(const player_position1d_cmd_vel_t *msg);
PLAYERXDR_EXPORT player_position1d_cmd_vel_t * player_position1d_cmd_vel_t_clone(const player_position1d_cmd_vel_t *msg);
PLAYERXDR_EXPORT void player_position1d_cmd_vel_t_free(player_position1d_cmd_vel_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_cmd_vel_t_sizeof(player_position1d_cmd_vel_t *msg);
int xdr_player_position1d_cmd_pos_t (XDR* xdrs, player_position1d_cmd_pos_t * msg);
PLAYERXDR_EXPORT int player_position1d_cmd_pos_pack(void* buf, size_t buflen, player_position1d_cmd_pos_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_cmd_pos_t_copy(player_position1d_cmd_pos_t *dest, const player_position1d_cmd_pos_t *src);
PLAYERXDR_EXPORT void player_position1d_cmd_pos_t_cleanup(const player_position1d_cmd_pos_t *msg);
PLAYERXDR_EXPORT player_position1d_cmd_pos_t * player_position1d_cmd_pos_t_clone(const player_position1d_cmd_pos_t *msg);
PLAYERXDR_EXPORT void player_position1d_cmd_pos_t_free(player_position1d_cmd_pos_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_cmd_pos_t_sizeof(player_position1d_cmd_pos_t *msg);
int xdr_player_position1d_geom_t (XDR* xdrs, player_position1d_geom_t * msg);
PLAYERXDR_EXPORT int player_position1d_geom_pack(void* buf, size_t buflen, player_position1d_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_geom_t_copy(player_position1d_geom_t *dest, const player_position1d_geom_t *src);
PLAYERXDR_EXPORT void player_position1d_geom_t_cleanup(const player_position1d_geom_t *msg);
PLAYERXDR_EXPORT player_position1d_geom_t * player_position1d_geom_t_clone(const player_position1d_geom_t *msg);
PLAYERXDR_EXPORT void player_position1d_geom_t_free(player_position1d_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_geom_t_sizeof(player_position1d_geom_t *msg);
int xdr_player_position1d_power_config_t (XDR* xdrs, player_position1d_power_config_t * msg);
PLAYERXDR_EXPORT int player_position1d_power_config_pack(void* buf, size_t buflen, player_position1d_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_power_config_t_copy(player_position1d_power_config_t *dest, const player_position1d_power_config_t *src);
PLAYERXDR_EXPORT void player_position1d_power_config_t_cleanup(const player_position1d_power_config_t *msg);
PLAYERXDR_EXPORT player_position1d_power_config_t * player_position1d_power_config_t_clone(const player_position1d_power_config_t *msg);
PLAYERXDR_EXPORT void player_position1d_power_config_t_free(player_position1d_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_power_config_t_sizeof(player_position1d_power_config_t *msg);
int xdr_player_position1d_velocity_mode_config_t (XDR* xdrs, player_position1d_velocity_mode_config_t * msg);
PLAYERXDR_EXPORT int player_position1d_velocity_mode_config_pack(void* buf, size_t buflen, player_position1d_velocity_mode_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_velocity_mode_config_t_copy(player_position1d_velocity_mode_config_t *dest, const player_position1d_velocity_mode_config_t *src);
PLAYERXDR_EXPORT void player_position1d_velocity_mode_config_t_cleanup(const player_position1d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT player_position1d_velocity_mode_config_t * player_position1d_velocity_mode_config_t_clone(const player_position1d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT void player_position1d_velocity_mode_config_t_free(player_position1d_velocity_mode_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_velocity_mode_config_t_sizeof(player_position1d_velocity_mode_config_t *msg);
int xdr_player_position1d_reset_odom_config_t (XDR* xdrs, player_position1d_reset_odom_config_t * msg);
PLAYERXDR_EXPORT int player_position1d_reset_odom_config_pack(void* buf, size_t buflen, player_position1d_reset_odom_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_reset_odom_config_t_copy(player_position1d_reset_odom_config_t *dest, const player_position1d_reset_odom_config_t *src);
PLAYERXDR_EXPORT void player_position1d_reset_odom_config_t_cleanup(const player_position1d_reset_odom_config_t *msg);
PLAYERXDR_EXPORT player_position1d_reset_odom_config_t * player_position1d_reset_odom_config_t_clone(const player_position1d_reset_odom_config_t *msg);
PLAYERXDR_EXPORT void player_position1d_reset_odom_config_t_free(player_position1d_reset_odom_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_reset_odom_config_t_sizeof(player_position1d_reset_odom_config_t *msg);
int xdr_player_position1d_position_mode_req_t (XDR* xdrs, player_position1d_position_mode_req_t * msg);
PLAYERXDR_EXPORT int player_position1d_position_mode_req_pack(void* buf, size_t buflen, player_position1d_position_mode_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_position_mode_req_t_copy(player_position1d_position_mode_req_t *dest, const player_position1d_position_mode_req_t *src);
PLAYERXDR_EXPORT void player_position1d_position_mode_req_t_cleanup(const player_position1d_position_mode_req_t *msg);
PLAYERXDR_EXPORT player_position1d_position_mode_req_t * player_position1d_position_mode_req_t_clone(const player_position1d_position_mode_req_t *msg);
PLAYERXDR_EXPORT void player_position1d_position_mode_req_t_free(player_position1d_position_mode_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_position_mode_req_t_sizeof(player_position1d_position_mode_req_t *msg);
int xdr_player_position1d_set_odom_req_t (XDR* xdrs, player_position1d_set_odom_req_t * msg);
PLAYERXDR_EXPORT int player_position1d_set_odom_req_pack(void* buf, size_t buflen, player_position1d_set_odom_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_set_odom_req_t_copy(player_position1d_set_odom_req_t *dest, const player_position1d_set_odom_req_t *src);
PLAYERXDR_EXPORT void player_position1d_set_odom_req_t_cleanup(const player_position1d_set_odom_req_t *msg);
PLAYERXDR_EXPORT player_position1d_set_odom_req_t * player_position1d_set_odom_req_t_clone(const player_position1d_set_odom_req_t *msg);
PLAYERXDR_EXPORT void player_position1d_set_odom_req_t_free(player_position1d_set_odom_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_set_odom_req_t_sizeof(player_position1d_set_odom_req_t *msg);
int xdr_player_position1d_speed_pid_req_t (XDR* xdrs, player_position1d_speed_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position1d_speed_pid_req_pack(void* buf, size_t buflen, player_position1d_speed_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_speed_pid_req_t_copy(player_position1d_speed_pid_req_t *dest, const player_position1d_speed_pid_req_t *src);
PLAYERXDR_EXPORT void player_position1d_speed_pid_req_t_cleanup(const player_position1d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT player_position1d_speed_pid_req_t * player_position1d_speed_pid_req_t_clone(const player_position1d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position1d_speed_pid_req_t_free(player_position1d_speed_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_speed_pid_req_t_sizeof(player_position1d_speed_pid_req_t *msg);
int xdr_player_position1d_position_pid_req_t (XDR* xdrs, player_position1d_position_pid_req_t * msg);
PLAYERXDR_EXPORT int player_position1d_position_pid_req_pack(void* buf, size_t buflen, player_position1d_position_pid_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_position_pid_req_t_copy(player_position1d_position_pid_req_t *dest, const player_position1d_position_pid_req_t *src);
PLAYERXDR_EXPORT void player_position1d_position_pid_req_t_cleanup(const player_position1d_position_pid_req_t *msg);
PLAYERXDR_EXPORT player_position1d_position_pid_req_t * player_position1d_position_pid_req_t_clone(const player_position1d_position_pid_req_t *msg);
PLAYERXDR_EXPORT void player_position1d_position_pid_req_t_free(player_position1d_position_pid_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_position_pid_req_t_sizeof(player_position1d_position_pid_req_t *msg);
int xdr_player_position1d_speed_prof_req_t (XDR* xdrs, player_position1d_speed_prof_req_t * msg);
PLAYERXDR_EXPORT int player_position1d_speed_prof_req_pack(void* buf, size_t buflen, player_position1d_speed_prof_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_position1d_speed_prof_req_t_copy(player_position1d_speed_prof_req_t *dest, const player_position1d_speed_prof_req_t *src);
PLAYERXDR_EXPORT void player_position1d_speed_prof_req_t_cleanup(const player_position1d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT player_position1d_speed_prof_req_t * player_position1d_speed_prof_req_t_clone(const player_position1d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT void player_position1d_speed_prof_req_t_free(player_position1d_speed_prof_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_position1d_speed_prof_req_t_sizeof(player_position1d_speed_prof_req_t *msg);
int xdr_player_actarray_actuator_t (XDR* xdrs, player_actarray_actuator_t * msg);
PLAYERXDR_EXPORT int player_actarray_actuator_pack(void* buf, size_t buflen, player_actarray_actuator_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_actuator_t_copy(player_actarray_actuator_t *dest, const player_actarray_actuator_t *src);
PLAYERXDR_EXPORT void player_actarray_actuator_t_cleanup(const player_actarray_actuator_t *msg);
PLAYERXDR_EXPORT player_actarray_actuator_t * player_actarray_actuator_t_clone(const player_actarray_actuator_t *msg);
PLAYERXDR_EXPORT void player_actarray_actuator_t_free(player_actarray_actuator_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_actuator_t_sizeof(player_actarray_actuator_t *msg);
int xdr_player_actarray_data_t (XDR* xdrs, player_actarray_data_t * msg);
PLAYERXDR_EXPORT int player_actarray_data_pack(void* buf, size_t buflen, player_actarray_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_data_t_copy(player_actarray_data_t *dest, const player_actarray_data_t *src);
PLAYERXDR_EXPORT void player_actarray_data_t_cleanup(const player_actarray_data_t *msg);
PLAYERXDR_EXPORT player_actarray_data_t * player_actarray_data_t_clone(const player_actarray_data_t *msg);
PLAYERXDR_EXPORT void player_actarray_data_t_free(player_actarray_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_data_t_sizeof(player_actarray_data_t *msg);
int xdr_player_actarray_actuatorgeom_t (XDR* xdrs, player_actarray_actuatorgeom_t * msg);
PLAYERXDR_EXPORT int player_actarray_actuatorgeom_pack(void* buf, size_t buflen, player_actarray_actuatorgeom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_actuatorgeom_t_copy(player_actarray_actuatorgeom_t *dest, const player_actarray_actuatorgeom_t *src);
PLAYERXDR_EXPORT void player_actarray_actuatorgeom_t_cleanup(const player_actarray_actuatorgeom_t *msg);
PLAYERXDR_EXPORT player_actarray_actuatorgeom_t * player_actarray_actuatorgeom_t_clone(const player_actarray_actuatorgeom_t *msg);
PLAYERXDR_EXPORT void player_actarray_actuatorgeom_t_free(player_actarray_actuatorgeom_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_actuatorgeom_t_sizeof(player_actarray_actuatorgeom_t *msg);
int xdr_player_actarray_geom_t (XDR* xdrs, player_actarray_geom_t * msg);
PLAYERXDR_EXPORT int player_actarray_geom_pack(void* buf, size_t buflen, player_actarray_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_geom_t_copy(player_actarray_geom_t *dest, const player_actarray_geom_t *src);
PLAYERXDR_EXPORT void player_actarray_geom_t_cleanup(const player_actarray_geom_t *msg);
PLAYERXDR_EXPORT player_actarray_geom_t * player_actarray_geom_t_clone(const player_actarray_geom_t *msg);
PLAYERXDR_EXPORT void player_actarray_geom_t_free(player_actarray_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_geom_t_sizeof(player_actarray_geom_t *msg);
int xdr_player_actarray_position_cmd_t (XDR* xdrs, player_actarray_position_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_position_cmd_pack(void* buf, size_t buflen, player_actarray_position_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_position_cmd_t_copy(player_actarray_position_cmd_t *dest, const player_actarray_position_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_position_cmd_t_cleanup(const player_actarray_position_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_position_cmd_t * player_actarray_position_cmd_t_clone(const player_actarray_position_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_position_cmd_t_free(player_actarray_position_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_position_cmd_t_sizeof(player_actarray_position_cmd_t *msg);
int xdr_player_actarray_multi_position_cmd_t (XDR* xdrs, player_actarray_multi_position_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_multi_position_cmd_pack(void* buf, size_t buflen, player_actarray_multi_position_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_position_cmd_t_copy(player_actarray_multi_position_cmd_t *dest, const player_actarray_multi_position_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_multi_position_cmd_t_cleanup(const player_actarray_multi_position_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_multi_position_cmd_t * player_actarray_multi_position_cmd_t_clone(const player_actarray_multi_position_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_multi_position_cmd_t_free(player_actarray_multi_position_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_position_cmd_t_sizeof(player_actarray_multi_position_cmd_t *msg);
int xdr_player_actarray_speed_cmd_t (XDR* xdrs, player_actarray_speed_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_speed_cmd_pack(void* buf, size_t buflen, player_actarray_speed_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_speed_cmd_t_copy(player_actarray_speed_cmd_t *dest, const player_actarray_speed_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_speed_cmd_t_cleanup(const player_actarray_speed_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_speed_cmd_t * player_actarray_speed_cmd_t_clone(const player_actarray_speed_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_speed_cmd_t_free(player_actarray_speed_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_speed_cmd_t_sizeof(player_actarray_speed_cmd_t *msg);
int xdr_player_actarray_multi_speed_cmd_t (XDR* xdrs, player_actarray_multi_speed_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_multi_speed_cmd_pack(void* buf, size_t buflen, player_actarray_multi_speed_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_speed_cmd_t_copy(player_actarray_multi_speed_cmd_t *dest, const player_actarray_multi_speed_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_multi_speed_cmd_t_cleanup(const player_actarray_multi_speed_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_multi_speed_cmd_t * player_actarray_multi_speed_cmd_t_clone(const player_actarray_multi_speed_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_multi_speed_cmd_t_free(player_actarray_multi_speed_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_speed_cmd_t_sizeof(player_actarray_multi_speed_cmd_t *msg);
int xdr_player_actarray_home_cmd_t (XDR* xdrs, player_actarray_home_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_home_cmd_pack(void* buf, size_t buflen, player_actarray_home_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_home_cmd_t_copy(player_actarray_home_cmd_t *dest, const player_actarray_home_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_home_cmd_t_cleanup(const player_actarray_home_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_home_cmd_t * player_actarray_home_cmd_t_clone(const player_actarray_home_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_home_cmd_t_free(player_actarray_home_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_home_cmd_t_sizeof(player_actarray_home_cmd_t *msg);
int xdr_player_actarray_current_cmd_t (XDR* xdrs, player_actarray_current_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_current_cmd_pack(void* buf, size_t buflen, player_actarray_current_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_current_cmd_t_copy(player_actarray_current_cmd_t *dest, const player_actarray_current_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_current_cmd_t_cleanup(const player_actarray_current_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_current_cmd_t * player_actarray_current_cmd_t_clone(const player_actarray_current_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_current_cmd_t_free(player_actarray_current_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_current_cmd_t_sizeof(player_actarray_current_cmd_t *msg);
int xdr_player_actarray_multi_current_cmd_t (XDR* xdrs, player_actarray_multi_current_cmd_t * msg);
PLAYERXDR_EXPORT int player_actarray_multi_current_cmd_pack(void* buf, size_t buflen, player_actarray_multi_current_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_current_cmd_t_copy(player_actarray_multi_current_cmd_t *dest, const player_actarray_multi_current_cmd_t *src);
PLAYERXDR_EXPORT void player_actarray_multi_current_cmd_t_cleanup(const player_actarray_multi_current_cmd_t *msg);
PLAYERXDR_EXPORT player_actarray_multi_current_cmd_t * player_actarray_multi_current_cmd_t_clone(const player_actarray_multi_current_cmd_t *msg);
PLAYERXDR_EXPORT void player_actarray_multi_current_cmd_t_free(player_actarray_multi_current_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_multi_current_cmd_t_sizeof(player_actarray_multi_current_cmd_t *msg);
int xdr_player_actarray_power_config_t (XDR* xdrs, player_actarray_power_config_t * msg);
PLAYERXDR_EXPORT int player_actarray_power_config_pack(void* buf, size_t buflen, player_actarray_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_power_config_t_copy(player_actarray_power_config_t *dest, const player_actarray_power_config_t *src);
PLAYERXDR_EXPORT void player_actarray_power_config_t_cleanup(const player_actarray_power_config_t *msg);
PLAYERXDR_EXPORT player_actarray_power_config_t * player_actarray_power_config_t_clone(const player_actarray_power_config_t *msg);
PLAYERXDR_EXPORT void player_actarray_power_config_t_free(player_actarray_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_power_config_t_sizeof(player_actarray_power_config_t *msg);
int xdr_player_actarray_brakes_config_t (XDR* xdrs, player_actarray_brakes_config_t * msg);
PLAYERXDR_EXPORT int player_actarray_brakes_config_pack(void* buf, size_t buflen, player_actarray_brakes_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_brakes_config_t_copy(player_actarray_brakes_config_t *dest, const player_actarray_brakes_config_t *src);
PLAYERXDR_EXPORT void player_actarray_brakes_config_t_cleanup(const player_actarray_brakes_config_t *msg);
PLAYERXDR_EXPORT player_actarray_brakes_config_t * player_actarray_brakes_config_t_clone(const player_actarray_brakes_config_t *msg);
PLAYERXDR_EXPORT void player_actarray_brakes_config_t_free(player_actarray_brakes_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_brakes_config_t_sizeof(player_actarray_brakes_config_t *msg);
int xdr_player_actarray_speed_config_t (XDR* xdrs, player_actarray_speed_config_t * msg);
PLAYERXDR_EXPORT int player_actarray_speed_config_pack(void* buf, size_t buflen, player_actarray_speed_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_speed_config_t_copy(player_actarray_speed_config_t *dest, const player_actarray_speed_config_t *src);
PLAYERXDR_EXPORT void player_actarray_speed_config_t_cleanup(const player_actarray_speed_config_t *msg);
PLAYERXDR_EXPORT player_actarray_speed_config_t * player_actarray_speed_config_t_clone(const player_actarray_speed_config_t *msg);
PLAYERXDR_EXPORT void player_actarray_speed_config_t_free(player_actarray_speed_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_speed_config_t_sizeof(player_actarray_speed_config_t *msg);
int xdr_player_actarray_accel_config_t (XDR* xdrs, player_actarray_accel_config_t * msg);
PLAYERXDR_EXPORT int player_actarray_accel_config_pack(void* buf, size_t buflen, player_actarray_accel_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_actarray_accel_config_t_copy(player_actarray_accel_config_t *dest, const player_actarray_accel_config_t *src);
PLAYERXDR_EXPORT void player_actarray_accel_config_t_cleanup(const player_actarray_accel_config_t *msg);
PLAYERXDR_EXPORT player_actarray_accel_config_t * player_actarray_accel_config_t_clone(const player_actarray_accel_config_t *msg);
PLAYERXDR_EXPORT void player_actarray_accel_config_t_free(player_actarray_accel_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_actarray_accel_config_t_sizeof(player_actarray_accel_config_t *msg);
int xdr_player_limb_data_t (XDR* xdrs, player_limb_data_t * msg);
PLAYERXDR_EXPORT int player_limb_data_pack(void* buf, size_t buflen, player_limb_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_data_t_copy(player_limb_data_t *dest, const player_limb_data_t *src);
PLAYERXDR_EXPORT void player_limb_data_t_cleanup(const player_limb_data_t *msg);
PLAYERXDR_EXPORT player_limb_data_t * player_limb_data_t_clone(const player_limb_data_t *msg);
PLAYERXDR_EXPORT void player_limb_data_t_free(player_limb_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_data_t_sizeof(player_limb_data_t *msg);
int xdr_player_limb_setpose_cmd_t (XDR* xdrs, player_limb_setpose_cmd_t * msg);
PLAYERXDR_EXPORT int player_limb_setpose_cmd_pack(void* buf, size_t buflen, player_limb_setpose_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_setpose_cmd_t_copy(player_limb_setpose_cmd_t *dest, const player_limb_setpose_cmd_t *src);
PLAYERXDR_EXPORT void player_limb_setpose_cmd_t_cleanup(const player_limb_setpose_cmd_t *msg);
PLAYERXDR_EXPORT player_limb_setpose_cmd_t * player_limb_setpose_cmd_t_clone(const player_limb_setpose_cmd_t *msg);
PLAYERXDR_EXPORT void player_limb_setpose_cmd_t_free(player_limb_setpose_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_setpose_cmd_t_sizeof(player_limb_setpose_cmd_t *msg);
int xdr_player_limb_setposition_cmd_t (XDR* xdrs, player_limb_setposition_cmd_t * msg);
PLAYERXDR_EXPORT int player_limb_setposition_cmd_pack(void* buf, size_t buflen, player_limb_setposition_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_setposition_cmd_t_copy(player_limb_setposition_cmd_t *dest, const player_limb_setposition_cmd_t *src);
PLAYERXDR_EXPORT void player_limb_setposition_cmd_t_cleanup(const player_limb_setposition_cmd_t *msg);
PLAYERXDR_EXPORT player_limb_setposition_cmd_t * player_limb_setposition_cmd_t_clone(const player_limb_setposition_cmd_t *msg);
PLAYERXDR_EXPORT void player_limb_setposition_cmd_t_free(player_limb_setposition_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_setposition_cmd_t_sizeof(player_limb_setposition_cmd_t *msg);
int xdr_player_limb_vecmove_cmd_t (XDR* xdrs, player_limb_vecmove_cmd_t * msg);
PLAYERXDR_EXPORT int player_limb_vecmove_cmd_pack(void* buf, size_t buflen, player_limb_vecmove_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_vecmove_cmd_t_copy(player_limb_vecmove_cmd_t *dest, const player_limb_vecmove_cmd_t *src);
PLAYERXDR_EXPORT void player_limb_vecmove_cmd_t_cleanup(const player_limb_vecmove_cmd_t *msg);
PLAYERXDR_EXPORT player_limb_vecmove_cmd_t * player_limb_vecmove_cmd_t_clone(const player_limb_vecmove_cmd_t *msg);
PLAYERXDR_EXPORT void player_limb_vecmove_cmd_t_free(player_limb_vecmove_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_vecmove_cmd_t_sizeof(player_limb_vecmove_cmd_t *msg);
int xdr_player_limb_power_req_t (XDR* xdrs, player_limb_power_req_t * msg);
PLAYERXDR_EXPORT int player_limb_power_req_pack(void* buf, size_t buflen, player_limb_power_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_power_req_t_copy(player_limb_power_req_t *dest, const player_limb_power_req_t *src);
PLAYERXDR_EXPORT void player_limb_power_req_t_cleanup(const player_limb_power_req_t *msg);
PLAYERXDR_EXPORT player_limb_power_req_t * player_limb_power_req_t_clone(const player_limb_power_req_t *msg);
PLAYERXDR_EXPORT void player_limb_power_req_t_free(player_limb_power_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_power_req_t_sizeof(player_limb_power_req_t *msg);
int xdr_player_limb_brakes_req_t (XDR* xdrs, player_limb_brakes_req_t * msg);
PLAYERXDR_EXPORT int player_limb_brakes_req_pack(void* buf, size_t buflen, player_limb_brakes_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_brakes_req_t_copy(player_limb_brakes_req_t *dest, const player_limb_brakes_req_t *src);
PLAYERXDR_EXPORT void player_limb_brakes_req_t_cleanup(const player_limb_brakes_req_t *msg);
PLAYERXDR_EXPORT player_limb_brakes_req_t * player_limb_brakes_req_t_clone(const player_limb_brakes_req_t *msg);
PLAYERXDR_EXPORT void player_limb_brakes_req_t_free(player_limb_brakes_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_brakes_req_t_sizeof(player_limb_brakes_req_t *msg);
int xdr_player_limb_geom_req_t (XDR* xdrs, player_limb_geom_req_t * msg);
PLAYERXDR_EXPORT int player_limb_geom_req_pack(void* buf, size_t buflen, player_limb_geom_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_geom_req_t_copy(player_limb_geom_req_t *dest, const player_limb_geom_req_t *src);
PLAYERXDR_EXPORT void player_limb_geom_req_t_cleanup(const player_limb_geom_req_t *msg);
PLAYERXDR_EXPORT player_limb_geom_req_t * player_limb_geom_req_t_clone(const player_limb_geom_req_t *msg);
PLAYERXDR_EXPORT void player_limb_geom_req_t_free(player_limb_geom_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_geom_req_t_sizeof(player_limb_geom_req_t *msg);
int xdr_player_limb_speed_req_t (XDR* xdrs, player_limb_speed_req_t * msg);
PLAYERXDR_EXPORT int player_limb_speed_req_pack(void* buf, size_t buflen, player_limb_speed_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_limb_speed_req_t_copy(player_limb_speed_req_t *dest, const player_limb_speed_req_t *src);
PLAYERXDR_EXPORT void player_limb_speed_req_t_cleanup(const player_limb_speed_req_t *msg);
PLAYERXDR_EXPORT player_limb_speed_req_t * player_limb_speed_req_t_clone(const player_limb_speed_req_t *msg);
PLAYERXDR_EXPORT void player_limb_speed_req_t_free(player_limb_speed_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_limb_speed_req_t_sizeof(player_limb_speed_req_t *msg);
int xdr_player_graphics2d_cmd_points_t (XDR* xdrs, player_graphics2d_cmd_points_t * msg);
PLAYERXDR_EXPORT int player_graphics2d_cmd_points_pack(void* buf, size_t buflen, player_graphics2d_cmd_points_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_points_t_copy(player_graphics2d_cmd_points_t *dest, const player_graphics2d_cmd_points_t *src);
PLAYERXDR_EXPORT void player_graphics2d_cmd_points_t_cleanup(const player_graphics2d_cmd_points_t *msg);
PLAYERXDR_EXPORT player_graphics2d_cmd_points_t * player_graphics2d_cmd_points_t_clone(const player_graphics2d_cmd_points_t *msg);
PLAYERXDR_EXPORT void player_graphics2d_cmd_points_t_free(player_graphics2d_cmd_points_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_points_t_sizeof(player_graphics2d_cmd_points_t *msg);
int xdr_player_graphics2d_cmd_polyline_t (XDR* xdrs, player_graphics2d_cmd_polyline_t * msg);
PLAYERXDR_EXPORT int player_graphics2d_cmd_polyline_pack(void* buf, size_t buflen, player_graphics2d_cmd_polyline_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_polyline_t_copy(player_graphics2d_cmd_polyline_t *dest, const player_graphics2d_cmd_polyline_t *src);
PLAYERXDR_EXPORT void player_graphics2d_cmd_polyline_t_cleanup(const player_graphics2d_cmd_polyline_t *msg);
PLAYERXDR_EXPORT player_graphics2d_cmd_polyline_t * player_graphics2d_cmd_polyline_t_clone(const player_graphics2d_cmd_polyline_t *msg);
PLAYERXDR_EXPORT void player_graphics2d_cmd_polyline_t_free(player_graphics2d_cmd_polyline_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_polyline_t_sizeof(player_graphics2d_cmd_polyline_t *msg);
int xdr_player_graphics2d_cmd_polygon_t (XDR* xdrs, player_graphics2d_cmd_polygon_t * msg);
PLAYERXDR_EXPORT int player_graphics2d_cmd_polygon_pack(void* buf, size_t buflen, player_graphics2d_cmd_polygon_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_polygon_t_copy(player_graphics2d_cmd_polygon_t *dest, const player_graphics2d_cmd_polygon_t *src);
PLAYERXDR_EXPORT void player_graphics2d_cmd_polygon_t_cleanup(const player_graphics2d_cmd_polygon_t *msg);
PLAYERXDR_EXPORT player_graphics2d_cmd_polygon_t * player_graphics2d_cmd_polygon_t_clone(const player_graphics2d_cmd_polygon_t *msg);
PLAYERXDR_EXPORT void player_graphics2d_cmd_polygon_t_free(player_graphics2d_cmd_polygon_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_polygon_t_sizeof(player_graphics2d_cmd_polygon_t *msg);
int xdr_player_graphics2d_cmd_multiline_t (XDR* xdrs, player_graphics2d_cmd_multiline_t * msg);
PLAYERXDR_EXPORT int player_graphics2d_cmd_multiline_pack(void* buf, size_t buflen, player_graphics2d_cmd_multiline_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_multiline_t_copy(player_graphics2d_cmd_multiline_t *dest, const player_graphics2d_cmd_multiline_t *src);
PLAYERXDR_EXPORT void player_graphics2d_cmd_multiline_t_cleanup(const player_graphics2d_cmd_multiline_t *msg);
PLAYERXDR_EXPORT player_graphics2d_cmd_multiline_t * player_graphics2d_cmd_multiline_t_clone(const player_graphics2d_cmd_multiline_t *msg);
PLAYERXDR_EXPORT void player_graphics2d_cmd_multiline_t_free(player_graphics2d_cmd_multiline_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics2d_cmd_multiline_t_sizeof(player_graphics2d_cmd_multiline_t *msg);
int xdr_player_rfid_tag_t (XDR* xdrs, player_rfid_tag_t * msg);
PLAYERXDR_EXPORT int player_rfid_tag_pack(void* buf, size_t buflen, player_rfid_tag_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_rfid_tag_t_copy(player_rfid_tag_t *dest, const player_rfid_tag_t *src);
PLAYERXDR_EXPORT void player_rfid_tag_t_cleanup(const player_rfid_tag_t *msg);
PLAYERXDR_EXPORT player_rfid_tag_t * player_rfid_tag_t_clone(const player_rfid_tag_t *msg);
PLAYERXDR_EXPORT void player_rfid_tag_t_free(player_rfid_tag_t *msg);
PLAYERXDR_EXPORT unsigned int player_rfid_tag_t_sizeof(player_rfid_tag_t *msg);
int xdr_player_rfid_data_t (XDR* xdrs, player_rfid_data_t * msg);
PLAYERXDR_EXPORT int player_rfid_data_pack(void* buf, size_t buflen, player_rfid_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_rfid_data_t_copy(player_rfid_data_t *dest, const player_rfid_data_t *src);
PLAYERXDR_EXPORT void player_rfid_data_t_cleanup(const player_rfid_data_t *msg);
PLAYERXDR_EXPORT player_rfid_data_t * player_rfid_data_t_clone(const player_rfid_data_t *msg);
PLAYERXDR_EXPORT void player_rfid_data_t_free(player_rfid_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_rfid_data_t_sizeof(player_rfid_data_t *msg);
int xdr_player_wsn_node_data_t (XDR* xdrs, player_wsn_node_data_t * msg);
PLAYERXDR_EXPORT int player_wsn_node_data_pack(void* buf, size_t buflen, player_wsn_node_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_node_data_t_copy(player_wsn_node_data_t *dest, const player_wsn_node_data_t *src);
PLAYERXDR_EXPORT void player_wsn_node_data_t_cleanup(const player_wsn_node_data_t *msg);
PLAYERXDR_EXPORT player_wsn_node_data_t * player_wsn_node_data_t_clone(const player_wsn_node_data_t *msg);
PLAYERXDR_EXPORT void player_wsn_node_data_t_free(player_wsn_node_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_node_data_t_sizeof(player_wsn_node_data_t *msg);
int xdr_player_wsn_data_t (XDR* xdrs, player_wsn_data_t * msg);
PLAYERXDR_EXPORT int player_wsn_data_pack(void* buf, size_t buflen, player_wsn_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_data_t_copy(player_wsn_data_t *dest, const player_wsn_data_t *src);
PLAYERXDR_EXPORT void player_wsn_data_t_cleanup(const player_wsn_data_t *msg);
PLAYERXDR_EXPORT player_wsn_data_t * player_wsn_data_t_clone(const player_wsn_data_t *msg);
PLAYERXDR_EXPORT void player_wsn_data_t_free(player_wsn_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_data_t_sizeof(player_wsn_data_t *msg);
int xdr_player_wsn_cmd_t (XDR* xdrs, player_wsn_cmd_t * msg);
PLAYERXDR_EXPORT int player_wsn_cmd_pack(void* buf, size_t buflen, player_wsn_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_cmd_t_copy(player_wsn_cmd_t *dest, const player_wsn_cmd_t *src);
PLAYERXDR_EXPORT void player_wsn_cmd_t_cleanup(const player_wsn_cmd_t *msg);
PLAYERXDR_EXPORT player_wsn_cmd_t * player_wsn_cmd_t_clone(const player_wsn_cmd_t *msg);
PLAYERXDR_EXPORT void player_wsn_cmd_t_free(player_wsn_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_cmd_t_sizeof(player_wsn_cmd_t *msg);
int xdr_player_wsn_power_config_t (XDR* xdrs, player_wsn_power_config_t * msg);
PLAYERXDR_EXPORT int player_wsn_power_config_pack(void* buf, size_t buflen, player_wsn_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_power_config_t_copy(player_wsn_power_config_t *dest, const player_wsn_power_config_t *src);
PLAYERXDR_EXPORT void player_wsn_power_config_t_cleanup(const player_wsn_power_config_t *msg);
PLAYERXDR_EXPORT player_wsn_power_config_t * player_wsn_power_config_t_clone(const player_wsn_power_config_t *msg);
PLAYERXDR_EXPORT void player_wsn_power_config_t_free(player_wsn_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_power_config_t_sizeof(player_wsn_power_config_t *msg);
int xdr_player_wsn_datatype_config_t (XDR* xdrs, player_wsn_datatype_config_t * msg);
PLAYERXDR_EXPORT int player_wsn_datatype_config_pack(void* buf, size_t buflen, player_wsn_datatype_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_datatype_config_t_copy(player_wsn_datatype_config_t *dest, const player_wsn_datatype_config_t *src);
PLAYERXDR_EXPORT void player_wsn_datatype_config_t_cleanup(const player_wsn_datatype_config_t *msg);
PLAYERXDR_EXPORT player_wsn_datatype_config_t * player_wsn_datatype_config_t_clone(const player_wsn_datatype_config_t *msg);
PLAYERXDR_EXPORT void player_wsn_datatype_config_t_free(player_wsn_datatype_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_datatype_config_t_sizeof(player_wsn_datatype_config_t *msg);
int xdr_player_wsn_datafreq_config_t (XDR* xdrs, player_wsn_datafreq_config_t * msg);
PLAYERXDR_EXPORT int player_wsn_datafreq_config_pack(void* buf, size_t buflen, player_wsn_datafreq_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_wsn_datafreq_config_t_copy(player_wsn_datafreq_config_t *dest, const player_wsn_datafreq_config_t *src);
PLAYERXDR_EXPORT void player_wsn_datafreq_config_t_cleanup(const player_wsn_datafreq_config_t *msg);
PLAYERXDR_EXPORT player_wsn_datafreq_config_t * player_wsn_datafreq_config_t_clone(const player_wsn_datafreq_config_t *msg);
PLAYERXDR_EXPORT void player_wsn_datafreq_config_t_free(player_wsn_datafreq_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_wsn_datafreq_config_t_sizeof(player_wsn_datafreq_config_t *msg);
int xdr_player_graphics3d_cmd_draw_t (XDR* xdrs, player_graphics3d_cmd_draw_t * msg);
PLAYERXDR_EXPORT int player_graphics3d_cmd_draw_pack(void* buf, size_t buflen, player_graphics3d_cmd_draw_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_draw_t_copy(player_graphics3d_cmd_draw_t *dest, const player_graphics3d_cmd_draw_t *src);
PLAYERXDR_EXPORT void player_graphics3d_cmd_draw_t_cleanup(const player_graphics3d_cmd_draw_t *msg);
PLAYERXDR_EXPORT player_graphics3d_cmd_draw_t * player_graphics3d_cmd_draw_t_clone(const player_graphics3d_cmd_draw_t *msg);
PLAYERXDR_EXPORT void player_graphics3d_cmd_draw_t_free(player_graphics3d_cmd_draw_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_draw_t_sizeof(player_graphics3d_cmd_draw_t *msg);
int xdr_player_graphics3d_cmd_translate_t (XDR* xdrs, player_graphics3d_cmd_translate_t * msg);
PLAYERXDR_EXPORT int player_graphics3d_cmd_translate_pack(void* buf, size_t buflen, player_graphics3d_cmd_translate_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_translate_t_copy(player_graphics3d_cmd_translate_t *dest, const player_graphics3d_cmd_translate_t *src);
PLAYERXDR_EXPORT void player_graphics3d_cmd_translate_t_cleanup(const player_graphics3d_cmd_translate_t *msg);
PLAYERXDR_EXPORT player_graphics3d_cmd_translate_t * player_graphics3d_cmd_translate_t_clone(const player_graphics3d_cmd_translate_t *msg);
PLAYERXDR_EXPORT void player_graphics3d_cmd_translate_t_free(player_graphics3d_cmd_translate_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_translate_t_sizeof(player_graphics3d_cmd_translate_t *msg);
int xdr_player_graphics3d_cmd_rotate_t (XDR* xdrs, player_graphics3d_cmd_rotate_t * msg);
PLAYERXDR_EXPORT int player_graphics3d_cmd_rotate_pack(void* buf, size_t buflen, player_graphics3d_cmd_rotate_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_rotate_t_copy(player_graphics3d_cmd_rotate_t *dest, const player_graphics3d_cmd_rotate_t *src);
PLAYERXDR_EXPORT void player_graphics3d_cmd_rotate_t_cleanup(const player_graphics3d_cmd_rotate_t *msg);
PLAYERXDR_EXPORT player_graphics3d_cmd_rotate_t * player_graphics3d_cmd_rotate_t_clone(const player_graphics3d_cmd_rotate_t *msg);
PLAYERXDR_EXPORT void player_graphics3d_cmd_rotate_t_free(player_graphics3d_cmd_rotate_t *msg);
PLAYERXDR_EXPORT unsigned int player_graphics3d_cmd_rotate_t_sizeof(player_graphics3d_cmd_rotate_t *msg);
int xdr_player_health_cpu_t (XDR* xdrs, player_health_cpu_t * msg);
PLAYERXDR_EXPORT int player_health_cpu_pack(void* buf, size_t buflen, player_health_cpu_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_health_cpu_t_copy(player_health_cpu_t *dest, const player_health_cpu_t *src);
PLAYERXDR_EXPORT void player_health_cpu_t_cleanup(const player_health_cpu_t *msg);
PLAYERXDR_EXPORT player_health_cpu_t * player_health_cpu_t_clone(const player_health_cpu_t *msg);
PLAYERXDR_EXPORT void player_health_cpu_t_free(player_health_cpu_t *msg);
PLAYERXDR_EXPORT unsigned int player_health_cpu_t_sizeof(player_health_cpu_t *msg);
int xdr_player_health_memory_t (XDR* xdrs, player_health_memory_t * msg);
PLAYERXDR_EXPORT int player_health_memory_pack(void* buf, size_t buflen, player_health_memory_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_health_memory_t_copy(player_health_memory_t *dest, const player_health_memory_t *src);
PLAYERXDR_EXPORT void player_health_memory_t_cleanup(const player_health_memory_t *msg);
PLAYERXDR_EXPORT player_health_memory_t * player_health_memory_t_clone(const player_health_memory_t *msg);
PLAYERXDR_EXPORT void player_health_memory_t_free(player_health_memory_t *msg);
PLAYERXDR_EXPORT unsigned int player_health_memory_t_sizeof(player_health_memory_t *msg);
int xdr_player_health_data_t (XDR* xdrs, player_health_data_t * msg);
PLAYERXDR_EXPORT int player_health_data_pack(void* buf, size_t buflen, player_health_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_health_data_t_copy(player_health_data_t *dest, const player_health_data_t *src);
PLAYERXDR_EXPORT void player_health_data_t_cleanup(const player_health_data_t *msg);
PLAYERXDR_EXPORT player_health_data_t * player_health_data_t_clone(const player_health_data_t *msg);
PLAYERXDR_EXPORT void player_health_data_t_free(player_health_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_health_data_t_sizeof(player_health_data_t *msg);
int xdr_player_imu_data_state_t (XDR* xdrs, player_imu_data_state_t * msg);
PLAYERXDR_EXPORT int player_imu_data_state_pack(void* buf, size_t buflen, player_imu_data_state_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_data_state_t_copy(player_imu_data_state_t *dest, const player_imu_data_state_t *src);
PLAYERXDR_EXPORT void player_imu_data_state_t_cleanup(const player_imu_data_state_t *msg);
PLAYERXDR_EXPORT player_imu_data_state_t * player_imu_data_state_t_clone(const player_imu_data_state_t *msg);
PLAYERXDR_EXPORT void player_imu_data_state_t_free(player_imu_data_state_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_data_state_t_sizeof(player_imu_data_state_t *msg);
int xdr_player_imu_data_calib_t (XDR* xdrs, player_imu_data_calib_t * msg);
PLAYERXDR_EXPORT int player_imu_data_calib_pack(void* buf, size_t buflen, player_imu_data_calib_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_data_calib_t_copy(player_imu_data_calib_t *dest, const player_imu_data_calib_t *src);
PLAYERXDR_EXPORT void player_imu_data_calib_t_cleanup(const player_imu_data_calib_t *msg);
PLAYERXDR_EXPORT player_imu_data_calib_t * player_imu_data_calib_t_clone(const player_imu_data_calib_t *msg);
PLAYERXDR_EXPORT void player_imu_data_calib_t_free(player_imu_data_calib_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_data_calib_t_sizeof(player_imu_data_calib_t *msg);
int xdr_player_imu_data_quat_t (XDR* xdrs, player_imu_data_quat_t * msg);
PLAYERXDR_EXPORT int player_imu_data_quat_pack(void* buf, size_t buflen, player_imu_data_quat_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_data_quat_t_copy(player_imu_data_quat_t *dest, const player_imu_data_quat_t *src);
PLAYERXDR_EXPORT void player_imu_data_quat_t_cleanup(const player_imu_data_quat_t *msg);
PLAYERXDR_EXPORT player_imu_data_quat_t * player_imu_data_quat_t_clone(const player_imu_data_quat_t *msg);
PLAYERXDR_EXPORT void player_imu_data_quat_t_free(player_imu_data_quat_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_data_quat_t_sizeof(player_imu_data_quat_t *msg);
int xdr_player_imu_data_euler_t (XDR* xdrs, player_imu_data_euler_t * msg);
PLAYERXDR_EXPORT int player_imu_data_euler_pack(void* buf, size_t buflen, player_imu_data_euler_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_data_euler_t_copy(player_imu_data_euler_t *dest, const player_imu_data_euler_t *src);
PLAYERXDR_EXPORT void player_imu_data_euler_t_cleanup(const player_imu_data_euler_t *msg);
PLAYERXDR_EXPORT player_imu_data_euler_t * player_imu_data_euler_t_clone(const player_imu_data_euler_t *msg);
PLAYERXDR_EXPORT void player_imu_data_euler_t_free(player_imu_data_euler_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_data_euler_t_sizeof(player_imu_data_euler_t *msg);
int xdr_player_imu_data_fullstate_t (XDR* xdrs, player_imu_data_fullstate_t * msg);
PLAYERXDR_EXPORT int player_imu_data_fullstate_pack(void* buf, size_t buflen, player_imu_data_fullstate_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_data_fullstate_t_copy(player_imu_data_fullstate_t *dest, const player_imu_data_fullstate_t *src);
PLAYERXDR_EXPORT void player_imu_data_fullstate_t_cleanup(const player_imu_data_fullstate_t *msg);
PLAYERXDR_EXPORT player_imu_data_fullstate_t * player_imu_data_fullstate_t_clone(const player_imu_data_fullstate_t *msg);
PLAYERXDR_EXPORT void player_imu_data_fullstate_t_free(player_imu_data_fullstate_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_data_fullstate_t_sizeof(player_imu_data_fullstate_t *msg);
int xdr_player_imu_datatype_config_t (XDR* xdrs, player_imu_datatype_config_t * msg);
PLAYERXDR_EXPORT int player_imu_datatype_config_pack(void* buf, size_t buflen, player_imu_datatype_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_datatype_config_t_copy(player_imu_datatype_config_t *dest, const player_imu_datatype_config_t *src);
PLAYERXDR_EXPORT void player_imu_datatype_config_t_cleanup(const player_imu_datatype_config_t *msg);
PLAYERXDR_EXPORT player_imu_datatype_config_t * player_imu_datatype_config_t_clone(const player_imu_datatype_config_t *msg);
PLAYERXDR_EXPORT void player_imu_datatype_config_t_free(player_imu_datatype_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_datatype_config_t_sizeof(player_imu_datatype_config_t *msg);
int xdr_player_imu_reset_orientation_config_t (XDR* xdrs, player_imu_reset_orientation_config_t * msg);
PLAYERXDR_EXPORT int player_imu_reset_orientation_config_pack(void* buf, size_t buflen, player_imu_reset_orientation_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_reset_orientation_config_t_copy(player_imu_reset_orientation_config_t *dest, const player_imu_reset_orientation_config_t *src);
PLAYERXDR_EXPORT void player_imu_reset_orientation_config_t_cleanup(const player_imu_reset_orientation_config_t *msg);
PLAYERXDR_EXPORT player_imu_reset_orientation_config_t * player_imu_reset_orientation_config_t_clone(const player_imu_reset_orientation_config_t *msg);
PLAYERXDR_EXPORT void player_imu_reset_orientation_config_t_free(player_imu_reset_orientation_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_reset_orientation_config_t_sizeof(player_imu_reset_orientation_config_t *msg);
int xdr_player_imu_reset_euler_config_t (XDR* xdrs, player_imu_reset_euler_config_t * msg);
PLAYERXDR_EXPORT int player_imu_reset_euler_config_pack(void* buf, size_t buflen, player_imu_reset_euler_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_imu_reset_euler_config_t_copy(player_imu_reset_euler_config_t *dest, const player_imu_reset_euler_config_t *src);
PLAYERXDR_EXPORT void player_imu_reset_euler_config_t_cleanup(const player_imu_reset_euler_config_t *msg);
PLAYERXDR_EXPORT player_imu_reset_euler_config_t * player_imu_reset_euler_config_t_clone(const player_imu_reset_euler_config_t *msg);
PLAYERXDR_EXPORT void player_imu_reset_euler_config_t_free(player_imu_reset_euler_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_imu_reset_euler_config_t_sizeof(player_imu_reset_euler_config_t *msg);
int xdr_player_pointcloud3d_element_t (XDR* xdrs, player_pointcloud3d_element_t * msg);
PLAYERXDR_EXPORT int player_pointcloud3d_element_pack(void* buf, size_t buflen, player_pointcloud3d_element_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_element_t_copy(player_pointcloud3d_element_t *dest, const player_pointcloud3d_element_t *src);
PLAYERXDR_EXPORT void player_pointcloud3d_element_t_cleanup(const player_pointcloud3d_element_t *msg);
PLAYERXDR_EXPORT player_pointcloud3d_element_t * player_pointcloud3d_element_t_clone(const player_pointcloud3d_element_t *msg);
PLAYERXDR_EXPORT void player_pointcloud3d_element_t_free(player_pointcloud3d_element_t *msg);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_element_t_sizeof(player_pointcloud3d_element_t *msg);
int xdr_player_pointcloud3d_data_t (XDR* xdrs, player_pointcloud3d_data_t * msg);
PLAYERXDR_EXPORT int player_pointcloud3d_data_pack(void* buf, size_t buflen, player_pointcloud3d_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_data_t_copy(player_pointcloud3d_data_t *dest, const player_pointcloud3d_data_t *src);
PLAYERXDR_EXPORT void player_pointcloud3d_data_t_cleanup(const player_pointcloud3d_data_t *msg);
PLAYERXDR_EXPORT player_pointcloud3d_data_t * player_pointcloud3d_data_t_clone(const player_pointcloud3d_data_t *msg);
PLAYERXDR_EXPORT void player_pointcloud3d_data_t_free(player_pointcloud3d_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_data_t_sizeof(player_pointcloud3d_data_t *msg);
int xdr_player_ranger_config_t (XDR* xdrs, player_ranger_config_t * msg);
PLAYERXDR_EXPORT int player_ranger_config_pack(void* buf, size_t buflen, player_ranger_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_config_t_copy(player_ranger_config_t *dest, const player_ranger_config_t *src);
PLAYERXDR_EXPORT void player_ranger_config_t_cleanup(const player_ranger_config_t *msg);
PLAYERXDR_EXPORT player_ranger_config_t * player_ranger_config_t_clone(const player_ranger_config_t *msg);
PLAYERXDR_EXPORT void player_ranger_config_t_free(player_ranger_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_config_t_sizeof(player_ranger_config_t *msg);
int xdr_player_ranger_geom_t (XDR* xdrs, player_ranger_geom_t * msg);
PLAYERXDR_EXPORT int player_ranger_geom_pack(void* buf, size_t buflen, player_ranger_geom_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_geom_t_copy(player_ranger_geom_t *dest, const player_ranger_geom_t *src);
PLAYERXDR_EXPORT void player_ranger_geom_t_cleanup(const player_ranger_geom_t *msg);
PLAYERXDR_EXPORT player_ranger_geom_t * player_ranger_geom_t_clone(const player_ranger_geom_t *msg);
PLAYERXDR_EXPORT void player_ranger_geom_t_free(player_ranger_geom_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_geom_t_sizeof(player_ranger_geom_t *msg);
int xdr_player_ranger_data_range_t (XDR* xdrs, player_ranger_data_range_t * msg);
PLAYERXDR_EXPORT int player_ranger_data_range_pack(void* buf, size_t buflen, player_ranger_data_range_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_data_range_t_copy(player_ranger_data_range_t *dest, const player_ranger_data_range_t *src);
PLAYERXDR_EXPORT void player_ranger_data_range_t_cleanup(const player_ranger_data_range_t *msg);
PLAYERXDR_EXPORT player_ranger_data_range_t * player_ranger_data_range_t_clone(const player_ranger_data_range_t *msg);
PLAYERXDR_EXPORT void player_ranger_data_range_t_free(player_ranger_data_range_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_data_range_t_sizeof(player_ranger_data_range_t *msg);
int xdr_player_ranger_data_rangestamped_t (XDR* xdrs, player_ranger_data_rangestamped_t * msg);
PLAYERXDR_EXPORT int player_ranger_data_rangestamped_pack(void* buf, size_t buflen, player_ranger_data_rangestamped_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_data_rangestamped_t_copy(player_ranger_data_rangestamped_t *dest, const player_ranger_data_rangestamped_t *src);
PLAYERXDR_EXPORT void player_ranger_data_rangestamped_t_cleanup(const player_ranger_data_rangestamped_t *msg);
PLAYERXDR_EXPORT player_ranger_data_rangestamped_t * player_ranger_data_rangestamped_t_clone(const player_ranger_data_rangestamped_t *msg);
PLAYERXDR_EXPORT void player_ranger_data_rangestamped_t_free(player_ranger_data_rangestamped_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_data_rangestamped_t_sizeof(player_ranger_data_rangestamped_t *msg);
int xdr_player_ranger_data_intns_t (XDR* xdrs, player_ranger_data_intns_t * msg);
PLAYERXDR_EXPORT int player_ranger_data_intns_pack(void* buf, size_t buflen, player_ranger_data_intns_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_data_intns_t_copy(player_ranger_data_intns_t *dest, const player_ranger_data_intns_t *src);
PLAYERXDR_EXPORT void player_ranger_data_intns_t_cleanup(const player_ranger_data_intns_t *msg);
PLAYERXDR_EXPORT player_ranger_data_intns_t * player_ranger_data_intns_t_clone(const player_ranger_data_intns_t *msg);
PLAYERXDR_EXPORT void player_ranger_data_intns_t_free(player_ranger_data_intns_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_data_intns_t_sizeof(player_ranger_data_intns_t *msg);
int xdr_player_ranger_data_intnsstamped_t (XDR* xdrs, player_ranger_data_intnsstamped_t * msg);
PLAYERXDR_EXPORT int player_ranger_data_intnsstamped_pack(void* buf, size_t buflen, player_ranger_data_intnsstamped_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_data_intnsstamped_t_copy(player_ranger_data_intnsstamped_t *dest, const player_ranger_data_intnsstamped_t *src);
PLAYERXDR_EXPORT void player_ranger_data_intnsstamped_t_cleanup(const player_ranger_data_intnsstamped_t *msg);
PLAYERXDR_EXPORT player_ranger_data_intnsstamped_t * player_ranger_data_intnsstamped_t_clone(const player_ranger_data_intnsstamped_t *msg);
PLAYERXDR_EXPORT void player_ranger_data_intnsstamped_t_free(player_ranger_data_intnsstamped_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_data_intnsstamped_t_sizeof(player_ranger_data_intnsstamped_t *msg);
int xdr_player_ranger_power_config_t (XDR* xdrs, player_ranger_power_config_t * msg);
PLAYERXDR_EXPORT int player_ranger_power_config_pack(void* buf, size_t buflen, player_ranger_power_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_power_config_t_copy(player_ranger_power_config_t *dest, const player_ranger_power_config_t *src);
PLAYERXDR_EXPORT void player_ranger_power_config_t_cleanup(const player_ranger_power_config_t *msg);
PLAYERXDR_EXPORT player_ranger_power_config_t * player_ranger_power_config_t_clone(const player_ranger_power_config_t *msg);
PLAYERXDR_EXPORT void player_ranger_power_config_t_free(player_ranger_power_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_power_config_t_sizeof(player_ranger_power_config_t *msg);
int xdr_player_ranger_intns_config_t (XDR* xdrs, player_ranger_intns_config_t * msg);
PLAYERXDR_EXPORT int player_ranger_intns_config_pack(void* buf, size_t buflen, player_ranger_intns_config_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_ranger_intns_config_t_copy(player_ranger_intns_config_t *dest, const player_ranger_intns_config_t *src);
PLAYERXDR_EXPORT void player_ranger_intns_config_t_cleanup(const player_ranger_intns_config_t *msg);
PLAYERXDR_EXPORT player_ranger_intns_config_t * player_ranger_intns_config_t_clone(const player_ranger_intns_config_t *msg);
PLAYERXDR_EXPORT void player_ranger_intns_config_t_free(player_ranger_intns_config_t *msg);
PLAYERXDR_EXPORT unsigned int player_ranger_intns_config_t_sizeof(player_ranger_intns_config_t *msg);
int xdr_player_vectormap_feature_data_t (XDR* xdrs, player_vectormap_feature_data_t * msg);
PLAYERXDR_EXPORT int player_vectormap_feature_data_pack(void* buf, size_t buflen, player_vectormap_feature_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_vectormap_feature_data_t_copy(player_vectormap_feature_data_t *dest, const player_vectormap_feature_data_t *src);
PLAYERXDR_EXPORT void player_vectormap_feature_data_t_cleanup(const player_vectormap_feature_data_t *msg);
PLAYERXDR_EXPORT player_vectormap_feature_data_t * player_vectormap_feature_data_t_clone(const player_vectormap_feature_data_t *msg);
PLAYERXDR_EXPORT void player_vectormap_feature_data_t_free(player_vectormap_feature_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_vectormap_feature_data_t_sizeof(player_vectormap_feature_data_t *msg);
int xdr_player_vectormap_layer_info_t (XDR* xdrs, player_vectormap_layer_info_t * msg);
PLAYERXDR_EXPORT int player_vectormap_layer_info_pack(void* buf, size_t buflen, player_vectormap_layer_info_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_vectormap_layer_info_t_copy(player_vectormap_layer_info_t *dest, const player_vectormap_layer_info_t *src);
PLAYERXDR_EXPORT void player_vectormap_layer_info_t_cleanup(const player_vectormap_layer_info_t *msg);
PLAYERXDR_EXPORT player_vectormap_layer_info_t * player_vectormap_layer_info_t_clone(const player_vectormap_layer_info_t *msg);
PLAYERXDR_EXPORT void player_vectormap_layer_info_t_free(player_vectormap_layer_info_t *msg);
PLAYERXDR_EXPORT unsigned int player_vectormap_layer_info_t_sizeof(player_vectormap_layer_info_t *msg);
int xdr_player_vectormap_layer_data_t (XDR* xdrs, player_vectormap_layer_data_t * msg);
PLAYERXDR_EXPORT int player_vectormap_layer_data_pack(void* buf, size_t buflen, player_vectormap_layer_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_vectormap_layer_data_t_copy(player_vectormap_layer_data_t *dest, const player_vectormap_layer_data_t *src);
PLAYERXDR_EXPORT void player_vectormap_layer_data_t_cleanup(const player_vectormap_layer_data_t *msg);
PLAYERXDR_EXPORT player_vectormap_layer_data_t * player_vectormap_layer_data_t_clone(const player_vectormap_layer_data_t *msg);
PLAYERXDR_EXPORT void player_vectormap_layer_data_t_free(player_vectormap_layer_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_vectormap_layer_data_t_sizeof(player_vectormap_layer_data_t *msg);
int xdr_player_vectormap_info_t (XDR* xdrs, player_vectormap_info_t * msg);
PLAYERXDR_EXPORT int player_vectormap_info_pack(void* buf, size_t buflen, player_vectormap_info_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_vectormap_info_t_copy(player_vectormap_info_t *dest, const player_vectormap_info_t *src);
PLAYERXDR_EXPORT void player_vectormap_info_t_cleanup(const player_vectormap_info_t *msg);
PLAYERXDR_EXPORT player_vectormap_info_t * player_vectormap_info_t_clone(const player_vectormap_info_t *msg);
PLAYERXDR_EXPORT void player_vectormap_info_t_free(player_vectormap_info_t *msg);
PLAYERXDR_EXPORT unsigned int player_vectormap_info_t_sizeof(player_vectormap_info_t *msg);
int xdr_player_pointcloud3d_stereo_element_t (XDR* xdrs, player_pointcloud3d_stereo_element_t * msg);
PLAYERXDR_EXPORT int player_pointcloud3d_stereo_element_pack(void* buf, size_t buflen, player_pointcloud3d_stereo_element_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_stereo_element_t_copy(player_pointcloud3d_stereo_element_t *dest, const player_pointcloud3d_stereo_element_t *src);
PLAYERXDR_EXPORT void player_pointcloud3d_stereo_element_t_cleanup(const player_pointcloud3d_stereo_element_t *msg);
PLAYERXDR_EXPORT player_pointcloud3d_stereo_element_t * player_pointcloud3d_stereo_element_t_clone(const player_pointcloud3d_stereo_element_t *msg);
PLAYERXDR_EXPORT void player_pointcloud3d_stereo_element_t_free(player_pointcloud3d_stereo_element_t *msg);
PLAYERXDR_EXPORT unsigned int player_pointcloud3d_stereo_element_t_sizeof(player_pointcloud3d_stereo_element_t *msg);
int xdr_player_stereo_data_t (XDR* xdrs, player_stereo_data_t * msg);
PLAYERXDR_EXPORT int player_stereo_data_pack(void* buf, size_t buflen, player_stereo_data_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_stereo_data_t_copy(player_stereo_data_t *dest, const player_stereo_data_t *src);
PLAYERXDR_EXPORT void player_stereo_data_t_cleanup(const player_stereo_data_t *msg);
PLAYERXDR_EXPORT player_stereo_data_t * player_stereo_data_t_clone(const player_stereo_data_t *msg);
PLAYERXDR_EXPORT void player_stereo_data_t_free(player_stereo_data_t *msg);
PLAYERXDR_EXPORT unsigned int player_stereo_data_t_sizeof(player_stereo_data_t *msg);
int xdr_player_coopobject_header_t (XDR* xdrs, player_coopobject_header_t * msg);
PLAYERXDR_EXPORT int player_coopobject_header_pack(void* buf, size_t buflen, player_coopobject_header_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_header_t_copy(player_coopobject_header_t *dest, const player_coopobject_header_t *src);
PLAYERXDR_EXPORT void player_coopobject_header_t_cleanup(const player_coopobject_header_t *msg);
PLAYERXDR_EXPORT player_coopobject_header_t * player_coopobject_header_t_clone(const player_coopobject_header_t *msg);
PLAYERXDR_EXPORT void player_coopobject_header_t_free(player_coopobject_header_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_header_t_sizeof(player_coopobject_header_t *msg);
int xdr_player_coopobject_rssi_t (XDR* xdrs, player_coopobject_rssi_t * msg);
PLAYERXDR_EXPORT int player_coopobject_rssi_pack(void* buf, size_t buflen, player_coopobject_rssi_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_rssi_t_copy(player_coopobject_rssi_t *dest, const player_coopobject_rssi_t *src);
PLAYERXDR_EXPORT void player_coopobject_rssi_t_cleanup(const player_coopobject_rssi_t *msg);
PLAYERXDR_EXPORT player_coopobject_rssi_t * player_coopobject_rssi_t_clone(const player_coopobject_rssi_t *msg);
PLAYERXDR_EXPORT void player_coopobject_rssi_t_free(player_coopobject_rssi_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_rssi_t_sizeof(player_coopobject_rssi_t *msg);
int xdr_player_coopobject_position_t (XDR* xdrs, player_coopobject_position_t * msg);
PLAYERXDR_EXPORT int player_coopobject_position_pack(void* buf, size_t buflen, player_coopobject_position_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_position_t_copy(player_coopobject_position_t *dest, const player_coopobject_position_t *src);
PLAYERXDR_EXPORT void player_coopobject_position_t_cleanup(const player_coopobject_position_t *msg);
PLAYERXDR_EXPORT player_coopobject_position_t * player_coopobject_position_t_clone(const player_coopobject_position_t *msg);
PLAYERXDR_EXPORT void player_coopobject_position_t_free(player_coopobject_position_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_position_t_sizeof(player_coopobject_position_t *msg);
int xdr_player_coopobject_sensor_t (XDR* xdrs, player_coopobject_sensor_t * msg);
PLAYERXDR_EXPORT int player_coopobject_sensor_pack(void* buf, size_t buflen, player_coopobject_sensor_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_sensor_t_copy(player_coopobject_sensor_t *dest, const player_coopobject_sensor_t *src);
PLAYERXDR_EXPORT void player_coopobject_sensor_t_cleanup(const player_coopobject_sensor_t *msg);
PLAYERXDR_EXPORT player_coopobject_sensor_t * player_coopobject_sensor_t_clone(const player_coopobject_sensor_t *msg);
PLAYERXDR_EXPORT void player_coopobject_sensor_t_free(player_coopobject_sensor_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_sensor_t_sizeof(player_coopobject_sensor_t *msg);
int xdr_player_coopobject_data_sensor_t (XDR* xdrs, player_coopobject_data_sensor_t * msg);
PLAYERXDR_EXPORT int player_coopobject_data_sensor_pack(void* buf, size_t buflen, player_coopobject_data_sensor_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_data_sensor_t_copy(player_coopobject_data_sensor_t *dest, const player_coopobject_data_sensor_t *src);
PLAYERXDR_EXPORT void player_coopobject_data_sensor_t_cleanup(const player_coopobject_data_sensor_t *msg);
PLAYERXDR_EXPORT player_coopobject_data_sensor_t * player_coopobject_data_sensor_t_clone(const player_coopobject_data_sensor_t *msg);
PLAYERXDR_EXPORT void player_coopobject_data_sensor_t_free(player_coopobject_data_sensor_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_data_sensor_t_sizeof(player_coopobject_data_sensor_t *msg);
int xdr_player_coopobject_data_userdefined_t (XDR* xdrs, player_coopobject_data_userdefined_t * msg);
PLAYERXDR_EXPORT int player_coopobject_data_userdefined_pack(void* buf, size_t buflen, player_coopobject_data_userdefined_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_data_userdefined_t_copy(player_coopobject_data_userdefined_t *dest, const player_coopobject_data_userdefined_t *src);
PLAYERXDR_EXPORT void player_coopobject_data_userdefined_t_cleanup(const player_coopobject_data_userdefined_t *msg);
PLAYERXDR_EXPORT player_coopobject_data_userdefined_t * player_coopobject_data_userdefined_t_clone(const player_coopobject_data_userdefined_t *msg);
PLAYERXDR_EXPORT void player_coopobject_data_userdefined_t_free(player_coopobject_data_userdefined_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_data_userdefined_t_sizeof(player_coopobject_data_userdefined_t *msg);
int xdr_player_coopobject_req_t (XDR* xdrs, player_coopobject_req_t * msg);
PLAYERXDR_EXPORT int player_coopobject_req_pack(void* buf, size_t buflen, player_coopobject_req_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_req_t_copy(player_coopobject_req_t *dest, const player_coopobject_req_t *src);
PLAYERXDR_EXPORT void player_coopobject_req_t_cleanup(const player_coopobject_req_t *msg);
PLAYERXDR_EXPORT player_coopobject_req_t * player_coopobject_req_t_clone(const player_coopobject_req_t *msg);
PLAYERXDR_EXPORT void player_coopobject_req_t_free(player_coopobject_req_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_req_t_sizeof(player_coopobject_req_t *msg);
int xdr_player_coopobject_cmd_t (XDR* xdrs, player_coopobject_cmd_t * msg);
PLAYERXDR_EXPORT int player_coopobject_cmd_pack(void* buf, size_t buflen, player_coopobject_cmd_t * msg, int op);
PLAYERXDR_EXPORT unsigned int player_coopobject_cmd_t_copy(player_coopobject_cmd_t *dest, const player_coopobject_cmd_t *src);
PLAYERXDR_EXPORT void player_coopobject_cmd_t_cleanup(const player_coopobject_cmd_t *msg);
PLAYERXDR_EXPORT player_coopobject_cmd_t * player_coopobject_cmd_t_clone(const player_coopobject_cmd_t *msg);
PLAYERXDR_EXPORT void player_coopobject_cmd_t_free(player_coopobject_cmd_t *msg);
PLAYERXDR_EXPORT unsigned int player_coopobject_cmd_t_sizeof(player_coopobject_cmd_t *msg);

#ifdef __cplusplus
}
#endif

#endif
/** @} */
